@@ -64,17 +64,17 @@ Keyboard Shortcuts::
       [q]\t Quit
 """
 
+from tkinter import Button, Frame, IntVar, Label, Listbox, Menu, Scrollbar, Tk
 from tkinter.font import Font
-from tkinter import Listbox, IntVar, Button, Frame, Label, Menu, Scrollbar, Tk
 
+from nltk.draw import CFGEditor, TreeSegmentWidget, tree_to_treesegment
+from nltk.draw.util import CanvasFrame, EntryDialog, ShowText, TextWidget
+from nltk.parse import SteppingRecursiveDescentParser
 from nltk.tree import Tree
 from nltk.util import in_idle
-from nltk.parse import SteppingRecursiveDescentParser
-from nltk.draw.util import TextWidget, ShowText, CanvasFrame, EntryDialog
-from nltk.draw import CFGEditor, TreeSegmentWidget, tree_to_treesegment
 
 
-class RecursiveDescentApp(object):
+class RecursiveDescentApp:
     """
     A graphical tool for exploring the recursive descent parser.  The tool
     displays the parser's tree and the remaining text, and allows the
