@@ -8,9 +8,8 @@
 # Based on an Eliza implementation by Joe Strout <joe@strout.net>,
 # Jeff Epler <jepler@inetnebr.com> and Jez Higgins <jez@jezuk.co.uk>.
 
-import re
 import random
-
+import re
 
 reflections = {
     "i am": "you are",
@@ -32,7 +31,7 @@ reflections = {
 }
 
 
-class Chat(object):
+class Chat:
     def __init__(self, pairs, reflections={}):
         """
         Initialize the chatbot.  Pairs is a list of patterns and responses.  Each
@@ -56,7 +55,7 @@ class Chat(object):
     def _compile_reflections(self):
         sorted_refl = sorted(self._reflections, key=len, reverse=True)
         return re.compile(
-            r"\b({0})\b".format("|".join(map(re.escape, sorted_refl))), re.IGNORECASE
+            r"\b({})\b".format("|".join(map(re.escape, sorted_refl))), re.IGNORECASE
         )
 
     def _substitute(self, str):
