@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Classifier Utility Functions
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com> (minor additions)
 # URL: <http://nltk.org/>
@@ -78,7 +78,7 @@ def attested_labels(tokens):
         labels.  A classified token has the form ``(token, label)``.
     :type tokens: list
     """
-    return tuple(set(label for (tok, label) in tokens))
+    return tuple({label for (tok, label) in tokens})
 
 
 def log_likelihood(classifier, gold):
@@ -96,7 +96,7 @@ def accuracy(classifier, gold):
         return 0
 
 
-class CutoffChecker(object):
+class CutoffChecker:
     """
     A helper class that implements cutoff checks based on number of
     iterations and log likelihood.
@@ -181,9 +181,10 @@ def binary_names_demo_features(name):
 
 
 def names_demo(trainer, features=names_demo_features):
-    from nltk.corpus import names
     import random
 
+    from nltk.corpus import names
+
     # Construct a list of classified names, using the names corpus.
     namelist = [(name, "male") for name in names.words("male.txt")] + [
         (name, "female") for name in names.words("female.txt")
@@ -227,9 +228,10 @@ def names_demo(trainer, features=names_demo_features):
 
 
 def partial_names_demo(trainer, features=names_demo_features):
-    from nltk.corpus import names
     import random
 
+    from nltk.corpus import names
+
     male_names = names.words("male.txt")
     female_names = names.words("female.txt")
 
@@ -285,9 +287,10 @@ _inst_cache = {}
 
 
 def wsd_demo(trainer, word, features, n=1000):
-    from nltk.corpus import senseval
     import random
 
+    from nltk.corpus import senseval
+
     # Get the instances.
     print("Reading data...")
     global _inst_cache
@@ -296,7 +299,7 @@ def wsd_demo(trainer, word, features, n=1000):
     instances = _inst_cache[word][:]
     if n > len(instances):
         n = len(instances)
-    senses = list(set(l for (i, l) in instances))
+    senses = list({l for (i, l) in instances})
     print("  Senses: " + " ".join(senses))
 
     # Randomly split the names into a test & train set.
@@ -335,9 +338,9 @@ def check_megam_config():
     """
     try:
         _megam_bin
-    except NameError:
+    except NameError as e:
         err_msg = str(
             "Please configure your megam binary first, e.g.\n"
             ">>> nltk.config_megam('/usr/bin/local/megam')"
         )
-        raise NameError(err_msg)
+        raise NameError(err_msg) from e
