@@ -61,9 +61,9 @@ For example, to read a list of the words in the Brown Corpus, use
 
 import re
 
-from nltk.tokenize import RegexpTokenizer
-from nltk.corpus.util import LazyCorpusLoader
 from nltk.corpus.reader import *
+from nltk.corpus.util import LazyCorpusLoader
+from nltk.tokenize import RegexpTokenizer
 
 abc = LazyCorpusLoader(
     "abc",
@@ -300,10 +300,10 @@ swadesh = LazyCorpusLoader(
     "swadesh", SwadeshCorpusReader, r"(?!README|\.).*", encoding="utf8"
 )
 swadesh110 = LazyCorpusLoader(
-    'panlex_swadesh', PanlexSwadeshCorpusReader, r'swadesh110/.*\.txt', encoding='utf8'
+    "panlex_swadesh", PanlexSwadeshCorpusReader, r"swadesh110/.*\.txt", encoding="utf8"
 )
 swadesh207 = LazyCorpusLoader(
-    'panlex_swadesh', PanlexSwadeshCorpusReader, r'swadesh207/.*\.txt', encoding='utf8'
+    "panlex_swadesh", PanlexSwadeshCorpusReader, r"swadesh207/.*\.txt", encoding="utf8"
 )
 switchboard = LazyCorpusLoader("switchboard", SwitchboardCorpusReader, tagset="wsj")
 timit = LazyCorpusLoader("timit", TimitCorpusReader)
@@ -481,13 +481,3 @@ def demo():
 if __name__ == "__main__":
     # demo()
     pass
-
-# ** this is for unit testing **
-# unload all corpus after tests
-def teardown_module(module=None):
-    import nltk.corpus
-
-    for name in dir(nltk.corpus):
-        obj = getattr(nltk.corpus, name, None)
-        if isinstance(obj, CorpusReader) and hasattr(obj, "_unload"):
-            obj._unload()
