@@ -39,8 +39,7 @@ titles = {
 documents = sorted(titles)
 
 
-
-class IEERDocument(object):
+class IEERDocument:
     def __init__(self, text, docno=None, doctype=None, date_time=None, headline=""):
         self.text = text
         self.docno = docno
@@ -56,25 +55,13 @@ class IEERDocument(object):
                 " ".join([w for w in self.text.leaves() if w[:1] != "<"][:12]) + "..."
             )
         if self.docno is not None:
-            return "<IEERDocument %s: %r>" % (self.docno, headline)
+            return f"<IEERDocument {self.docno}: {headline!r}>"
         else:
             return "<IEERDocument: %r>" % headline
 
 
 class IEERCorpusReader(CorpusReader):
-    """
-    """
-
-    def raw(self, fileids=None):
-        if fileids is None:
-            fileids = self._fileids
-        elif isinstance(fileids, str):
-            fileids = [fileids]
-        contents = []
-        for f in fileids:
-            with self.open(f) as fp:
-                contents.append(fp.read())
-        return concat(contents)
+    """ """
 
     def docs(self, fileids=None):
         return concat(
