@@ -8,7 +8,6 @@
 from nltk.corpus.reader.api import *
 from nltk.corpus.reader.xmldocs import XMLCorpusReader
 
-
 PARA = re.compile(r"<p(?: [^>]*){0,1}>(.*?)</p>")
 SENT = re.compile(r"<s(?: [^>]*){0,1}>(.*?)</s>")
 
@@ -128,11 +127,14 @@ class Pl196xCorpusReader(CategorizedCorpusReader, XMLCorpusReader):
     def _resolve(self, fileids, categories, textids=None):
         tmp = None
         if (
-            len(list(
-                filter(
-                    lambda accessor: accessor is None, (fileids, categories, textids)
+            len(
+                list(
+                    filter(
+                        lambda accessor: accessor is None,
+                        (fileids, categories, textids),
+                    )
                 )
-            ))
+            )
             != 1
         ):
 
@@ -371,15 +373,3 @@ class Pl196xCorpusReader(CategorizedCorpusReader, XMLCorpusReader):
             return XMLCorpusReader.xml(self, fileids[0])
         else:
             raise TypeError("Expected a single file")
-
-    def raw(self, fileids=None, categories=None):
-        fileids, _ = self._resolve(fileids, categories)
-        if fileids is None:
-            fileids = self._fileids
-        elif isinstance(fileids, str):
-            fileids = [fileids]
-        contents = []
-        for f in fileids:
-            with self.open(f) as fp:
-                contents.append(fp.read())
-        return concat(contents)
