@@ -6,19 +6,23 @@
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-import os
 import bisect
+import os
+import pickle
 import re
 import tempfile
-import pickle
 from functools import reduce
 from xml.etree import ElementTree
 
-from nltk.tokenize import wordpunct_tokenize
+from nltk.data import (
+    FileSystemPathPointer,
+    PathPointer,
+    SeekableUnicodeStreamReader,
+    ZipFilePathPointer,
+)
 from nltk.internals import slice_bounds
-from nltk.data import PathPointer, FileSystemPathPointer, ZipFilePathPointer
-from nltk.data import SeekableUnicodeStreamReader
-from nltk.util import AbstractLazySequence, LazySubsequence, LazyConcatenation, py25
+from nltk.tokenize import wordpunct_tokenize
+from nltk.util import AbstractLazySequence, LazyConcatenation, LazySubsequence
 
 ######################################################################
 # { Corpus View
@@ -170,9 +174,7 @@ class StreamBackedCorpusView(AbstractLazySequence):
             else:
                 self._eofpos = os.stat(self._fileid).st_size
         except Exception as exc:
-            raise ValueError(
-                "Unable to open or access %r -- %s" % (fileid, exc)
-            ) from exc
+            raise ValueError(f"Unable to open or access {fileid!r} -- {exc}") from exc
 
         # Maintain a cache of the most recently read block, to
         # increase efficiency of random access.
@@ -308,9 +310,11 @@ class StreamBackedCorpusView(AbstractLazySequence):
             )
             num_toks = len(tokens)
             new_filepos = self._stream.tell()
-            assert new_filepos > filepos, (
-                "block reader %s() should consume at least 1 byte (filepos=%d)"
-                % (self.read_block.__name__, filepos)
+            assert (
+                new_filepos > filepos
+            ), "block reader %s() should consume at least 1 byte (filepos=%d)" % (
+                self.read_block.__name__,
+                filepos,
             )
 
             # Update our cache.
@@ -417,8 +421,7 @@ class ConcatenatedCorpusView(AbstractLazySequence):
                 self._open_piece = piece
 
             # Get everything we can from this piece.
-            for tok in piece.iterate_from(max(0, start_tok - offset)):
-                yield tok
+            yield from piece.iterate_from(max(0, start_tok - offset))
 
             # Update the offset table.
             if piecenum + 1 == len(self._offsets):
@@ -440,7 +443,7 @@ def concat(docs):
     if len(docs) == 0:
         raise ValueError("concat() expects at least one object!")
 
-    types = set(d.__class__ for d in docs)
+    types = {d.__class__ for d in docs}
 
     # If they're all strings, use string concatenation.
     if all(isinstance(doc, str) for doc in docs):
@@ -536,7 +539,7 @@ class PickleCorpusView(StreamBackedCorpusView):
             if os.path.exists(self._fileid):
                 try:
                     os.remove(self._fileid)
-                except (OSError, IOError):
+                except OSError:
                     pass
         self.__dict__.clear()  # make the garbage collector's job easier
 
@@ -563,7 +566,7 @@ class PickleCorpusView(StreamBackedCorpusView):
             cls.write(sequence, output_file)
             output_file.close()
             return PickleCorpusView(output_file_name, delete_on_gc)
-        except (OSError, IOError) as e:
+        except OSError as e:
             raise ValueError("Error while creating temp file: %s" % e) from e
 
 
@@ -812,11 +815,7 @@ def find_corpus_fileids(root, regexp):
     # or symlinked) subdirectories, and match paths against the regexp.
     elif isinstance(root, FileSystemPathPointer):
         items = []
-        # workaround for py25 which doesn't support followlinks
-        kwargs = {}
-        if not py25():
-            kwargs = {"followlinks": True}
-        for dirname, subdirs, fileids in os.walk(root.path, **kwargs):
+        for dirname, subdirs, fileids in os.walk(root.path):
             prefix = "".join("%s/" % p for p in _path_from(root.path, dirname))
             items += [
                 prefix + fileid
