@@ -11,16 +11,16 @@ Graphically display a Tree.
 
 from tkinter import IntVar, Menu, Tk
 
-from nltk.util import in_idle
-from nltk.tree import Tree
 from nltk.draw.util import (
+    BoxWidget,
     CanvasFrame,
     CanvasWidget,
-    BoxWidget,
-    TextWidget,
-    ParenWidget,
     OvalWidget,
+    ParenWidget,
+    TextWidget,
 )
+from nltk.tree import Tree
+from nltk.util import in_idle
 
 ##//////////////////////////////////////////////////////
 ##  Tree Segment
@@ -416,7 +416,7 @@ class TreeSegmentWidget(CanvasWidget):
         self._managing = False
 
     def __repr__(self):
-        return "[TreeSeg %s: %s]" % (self._label, self._subtrees)
+        return f"[TreeSeg {self._label}: {self._subtrees}]"
 
 
 def _tree_to_treeseg(
@@ -850,9 +850,9 @@ class TreeWidget(CanvasWidget):
 ##//////////////////////////////////////////////////////
 
 
-class TreeView(object):
+class TreeView:
     def __init__(self, *trees):
-        from math import sqrt, ceil
+        from math import ceil, sqrt
 
         self._trees = trees
 
