@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Context Free Grammars
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 #         Edward Loper <edloper@gmail.com>
 #         Jason Narad <jason.narad@gmail.com>
@@ -71,12 +70,10 @@ with the right hand side (*rhs*) in a tree (*tree*) is known as
 import re
 from functools import total_ordering
 
-from nltk.util import transitive_closure, invert_graph
+from nltk.featstruct import SLASH, TYPE, FeatDict, FeatStruct, FeatStructReader
 from nltk.internals import raise_unorderable_types
-
 from nltk.probability import ImmutableProbabilisticMixIn
-from nltk.featstruct import FeatStruct, FeatDict, FeatStructReader, SLASH, TYPE
-
+from nltk.util import invert_graph, transitive_closure
 
 #################################################################
 # Nonterminal
@@ -84,7 +81,7 @@ from nltk.featstruct import FeatStruct, FeatDict, FeatStructReader, SLASH, TYPE
 
 
 @total_ordering
-class Nonterminal(object):
+class Nonterminal:
     """
     A non-terminal symbol for a context free grammar.  ``Nonterminal``
     is a wrapper class for node values; it is used by ``Production``
@@ -113,7 +110,6 @@ class Nonterminal(object):
             hashable.
         """
         self._symbol = symbol
-        self._hash = hash(symbol)
 
     def symbol(self):
         """
@@ -142,7 +138,7 @@ class Nonterminal(object):
         return self._symbol < other._symbol
 
     def __hash__(self):
-        return self._hash
+        return hash(self._symbol)
 
     def __repr__(self):
         """
@@ -176,7 +172,7 @@ class Nonterminal(object):
         :type rhs: Nonterminal
         :rtype: Nonterminal
         """
-        return Nonterminal("%s/%s" % (self._symbol, rhs._symbol))
+        return Nonterminal(f"{self._symbol}/{rhs._symbol}")
 
     def __truediv__(self, rhs):
         """
@@ -254,8 +250,7 @@ def is_terminal(item):
 
 
 @total_ordering
-
-class Production(object):
+class Production:
     """
     A grammar production.  Each production maps a single symbol
     on the "left-hand side" to a sequence of symbols on the
@@ -290,7 +285,6 @@ class Production(object):
             )
         self._lhs = lhs
         self._rhs = tuple(rhs)
-        self._hash = hash((self._lhs, self._rhs))
 
     def lhs(self):
         """
@@ -376,8 +370,7 @@ class Production(object):
 
         :rtype: int
         """
-        return self._hash
-
+        return hash((self._lhs, self._rhs))
 
 
 class DependencyProduction(Production):
@@ -392,13 +385,12 @@ class DependencyProduction(Production):
 
         :rtype: str
         """
-        result = "'%s' ->" % (self._lhs,)
+        result = f"'{self._lhs}' ->"
         for elt in self._rhs:
-            result += " '%s'" % (elt,)
+            result += f" '{elt}'"
         return result
 
 
-
 class ProbabilisticProduction(Production, ImmutableProbabilisticMixIn):
     """
     A probabilistic context free grammar production.
@@ -449,8 +441,7 @@ class ProbabilisticProduction(Production, ImmutableProbabilisticMixIn):
 #################################################################
 
 
-
-class CFG(object):
+class CFG:
     """
     A context-free grammar.  A grammar consists of a start state and
     a set of productions.  The set of terminals and nonterminals is
@@ -481,7 +472,7 @@ class CFG(object):
 
         self._start = start
         self._productions = productions
-        self._categories = set(prod.lhs() for prod in productions)
+        self._categories = {prod.lhs() for prod in productions}
         self._calculate_indexes()
         self._calculate_grammar_forms()
         if calculate_leftcorners:
@@ -514,12 +505,8 @@ class CFG(object):
 
     def _calculate_leftcorners(self):
         # Calculate leftcorner relations, for use in optimized parsing.
-        self._immediate_leftcorner_categories = dict(
-            (cat, set([cat])) for cat in self._categories
-        )
-        self._immediate_leftcorner_words = dict(
-            (cat, set()) for cat in self._categories
-        )
+        self._immediate_leftcorner_categories = {cat: {cat} for cat in self._categories}
+        self._immediate_leftcorner_words = {cat: set() for cat in self._categories}
         for prod in self.productions():
             if len(prod) > 0:
                 cat, left = prod.lhs(), prod.rhs()[0]
@@ -629,7 +616,7 @@ class CFG(object):
         :return: the set of all leftcorners
         :rtype: set(Nonterminal)
         """
-        return self._leftcorners.get(cat, set([cat]))
+        return self._leftcorners.get(cat, {cat})
 
     def is_leftcorner(self, cat, left):
         """
@@ -662,7 +649,7 @@ class CFG(object):
         :return: the set of all parents to the leftcorner
         :rtype: set(Nonterminal)
         """
-        return self._leftcorner_parents.get(cat, set([cat]))
+        return self._leftcorner_parents.get(cat, {cat})
 
     def check_coverage(self, tokens):
         """
@@ -673,7 +660,7 @@ class CFG(object):
         """
         missing = [tok for tok in tokens if not self._lexical_index.get(tok)]
         if missing:
-            missing = ", ".join("%r" % (w,) for w in missing)
+            missing = ", ".join(f"{w!r}" for w in missing)
             raise ValueError(
                 "Grammar does not cover some of the " "input words: %r." % missing
             )
@@ -749,7 +736,7 @@ class CFG(object):
 
     def chomsky_normal_form(self, new_token_padding="@$@", flexible=False):
         """
-        Returns a new Grammer that is in chomsky normal
+        Returns a new Grammar that is in chomsky normal
         :param: new_token_padding
             Customise new rule formation during binarisation
         """
@@ -757,14 +744,14 @@ class CFG(object):
             return self
         if self.productions(empty=True):
             raise ValueError(
-                ("Grammar has Empty rules. " "Cannot deal with them at the moment")
+                "Grammar has Empty rules. " "Cannot deal with them at the moment"
             )
 
         # check for mixed rules
         for rule in self.productions():
             if rule.is_lexical() and len(rule.rhs()) > 1:
                 raise ValueError(
-                    "Cannot handled mixed rule {} => {}".format(rule.lhs(), rule.rhs())
+                    f"Cannot handled mixed rule {rule.lhs()} => {rule.rhs()}"
                 )
 
         step1 = CFG.eliminate_start(self)
@@ -772,7 +759,8 @@ class CFG(object):
         if flexible:
             return step2
         step3 = CFG.remove_unitary_rules(step2)
-        return step3
+        step4 = CFG(step3.start(), list(set(step3.productions())))
+        return step4
 
     @classmethod
     def remove_unitary_rules(cls, grammar):
@@ -1020,8 +1008,7 @@ class FeatureGrammar(CFG):
 
 
 @total_ordering
-
-class FeatureValueType(object):
+class FeatureValueType:
     """
     A helper class for ``FeatureGrammars``, designed to be different
     from ordinary strings.  This is to stop the ``FeatStruct``
@@ -1030,7 +1017,6 @@ class FeatureValueType(object):
 
     def __init__(self, value):
         self._value = value
-        self._hash = hash(value)
 
     def __repr__(self):
         return "<%s>" % self._value
@@ -1047,11 +1033,10 @@ class FeatureValueType(object):
         return self._value < other._value
 
     def __hash__(self):
-        return self._hash
+        return hash(self._value)
 
 
-
-class DependencyGrammar(object):
+class DependencyGrammar:
     """
     A dependency grammar.  A DependencyGrammar consists of a set of
     productions.  Each production specifies a head/modifier relationship
@@ -1076,8 +1061,8 @@ class DependencyGrammar(object):
                 continue
             try:
                 productions += _read_dependency_production(line)
-            except ValueError:
-                raise ValueError("Unable to parse line %s: %s" % (linenum, line))
+            except ValueError as e:
+                raise ValueError(f"Unable to parse line {linenum}: {line}") from e
         if len(productions) == 0:
             raise ValueError("No productions found!")
         return cls(productions)
@@ -1145,11 +1130,8 @@ class DependencyGrammar(object):
         return "Dependency grammar with %d productions" % len(self._productions)
 
 
-
-class ProbabilisticDependencyGrammar(object):
-    """
-
-    """
+class ProbabilisticDependencyGrammar:
+    """ """
 
     def __init__(self, productions, events, tags):
         self._productions = productions
@@ -1189,7 +1171,7 @@ class ProbabilisticDependencyGrammar(object):
             str += "\n  %d:%s" % (self._events[event], event)
         str += "\nTags:"
         for tag_word in self._tags:
-            str += "\n %s:\t(%s)" % (tag_word, self._tags[tag_word])
+            str += f"\n {tag_word}:\t({self._tags[tag_word]})"
         return str
 
     def __repr__(self):
@@ -1272,7 +1254,7 @@ class PCFG(CFG):
 
 
 def induce_pcfg(start, productions):
-    """
+    r"""
     Induce a PCFG grammar from a list of productions.
 
     The probability of a production A -> B C in a PCFG is:
@@ -1448,7 +1430,7 @@ def read_grammar(input, nonterm_parser, probabilistic=False, encoding=None):
                 # expand out the disjunctions on the RHS
                 productions += _read_production(line, nonterm_parser, probabilistic)
         except ValueError as e:
-            raise ValueError("Unable to parse line %s: %s\n%s" % (linenum + 1, line, e))
+            raise ValueError(f"Unable to parse line {linenum + 1}: {line}\n{e}") from e
 
     if not productions:
         raise ValueError("No productions found!")
@@ -1457,7 +1439,7 @@ def read_grammar(input, nonterm_parser, probabilistic=False, encoding=None):
     return (start, productions)
 
 
-_STANDARD_NONTERM_RE = re.compile("( [\w/][\w/^<>-]* ) \s*", re.VERBOSE)
+_STANDARD_NONTERM_RE = re.compile(r"( [\w/][\w/^<>-]* ) \s*", re.VERBOSE)
 
 
 def standard_nonterm_parser(string, pos):
@@ -1512,7 +1494,7 @@ def cfg_demo():
     A demonstration showing how ``CFGs`` can be created and used.
     """
 
-    from nltk import nonterminals, Production, CFG
+    from nltk import CFG, Production, nonterminals
 
     # Create some nonterminals
     S, NP, VP, PP = nonterminals("S, NP, VP, PP")
@@ -1594,9 +1576,8 @@ def pcfg_demo():
     A demonstration showing how a ``PCFG`` can be created and used.
     """
 
+    from nltk import induce_pcfg, treetransforms
     from nltk.corpus import treebank
-    from nltk import treetransforms
-    from nltk import induce_pcfg
     from nltk.parse import pchart
 
     pcfg_prods = toy_pcfg1.productions()
