@@ -210,14 +210,16 @@ on 2 preceding words. If you pass in a 4-word context, the first two words
 will be ignored.
 """
 
+from nltk.lm.counter import NgramCounter
 from nltk.lm.models import (
     MLE,
-    Lidstone,
-    Laplace,
-    WittenBellInterpolated,
+    AbsoluteDiscountingInterpolated,
     KneserNeyInterpolated,
+    Laplace,
+    Lidstone,
+    StupidBackoff,
+    WittenBellInterpolated,
 )
-from nltk.lm.counter import NgramCounter
 from nltk.lm.vocabulary import Vocabulary
 
 __all__ = [
@@ -228,4 +230,6 @@ __all__ = [
     "Laplace",
     "WittenBellInterpolated",
     "KneserNeyInterpolated",
+    "AbsoluteDiscountingInterpolated",
+    "StupidBackoff",
 ]
