@@ -13,39 +13,39 @@ NLTK Metrics
 Classes and methods for scoring processing modules.
 """
 
-from nltk.metrics.scores import (
-    accuracy,
-    precision,
-    recall,
-    f_measure,
-    log_likelihood,
-    approxrand,
+from nltk.metrics.agreement import AnnotationTask
+from nltk.metrics.aline import align
+from nltk.metrics.association import (
+    BigramAssocMeasures,
+    ContingencyMeasures,
+    NgramAssocMeasures,
+    QuadgramAssocMeasures,
+    TrigramAssocMeasures,
 )
 from nltk.metrics.confusionmatrix import ConfusionMatrix
 from nltk.metrics.distance import (
+    binary_distance,
+    custom_distance,
     edit_distance,
     edit_distance_align,
-    binary_distance,
+    fractional_presence,
+    interval_distance,
     jaccard_distance,
     masi_distance,
-    interval_distance,
-    custom_distance,
     presence,
-    fractional_presence,
 )
 from nltk.metrics.paice import Paice
-from nltk.metrics.segmentation import windowdiff, ghd, pk
-from nltk.metrics.agreement import AnnotationTask
-from nltk.metrics.association import (
-    NgramAssocMeasures,
-    BigramAssocMeasures,
-    TrigramAssocMeasures,
-    QuadgramAssocMeasures,
-    ContingencyMeasures,
+from nltk.metrics.scores import (
+    accuracy,
+    approxrand,
+    f_measure,
+    log_likelihood,
+    precision,
+    recall,
 )
+from nltk.metrics.segmentation import ghd, pk, windowdiff
 from nltk.metrics.spearman import (
-    spearman_correlation,
-    ranks_from_sequence,
     ranks_from_scores,
+    ranks_from_sequence,
+    spearman_correlation,
 )
-from nltk.metrics.aline import align
