@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Chart Parser for Feature-Based Grammars
 #
 # Copyright (C) 2001-2021 NLTK Project
@@ -13,31 +12,31 @@ feature structures as nodes.
 """
 from time import perf_counter
 
-from nltk.featstruct import FeatStruct, unify, TYPE, find_variables
-from nltk.sem import logic
-from nltk.tree import Tree
+from nltk.featstruct import TYPE, FeatStruct, find_variables, unify
 from nltk.grammar import (
-    Nonterminal,
-    Production,
     CFG,
     FeatStructNonterminal,
+    Nonterminal,
+    Production,
     is_nonterminal,
     is_terminal,
 )
 from nltk.parse.chart import (
-    TreeEdge,
+    BottomUpPredictCombineRule,
+    BottomUpPredictRule,
+    CachedTopDownPredictRule,
     Chart,
     ChartParser,
     EdgeI,
+    EmptyPredictRule,
     FundamentalRule,
     LeafInitRule,
-    EmptyPredictRule,
-    BottomUpPredictRule,
     SingleEdgeFundamentalRule,
-    BottomUpPredictCombineRule,
-    CachedTopDownPredictRule,
     TopDownInitRule,
+    TreeEdge,
 )
+from nltk.sem import logic
+from nltk.tree import Tree
 
 # ////////////////////////////////////////////////////////////
 # Tree Edge
@@ -150,7 +149,7 @@ class FeatureTreeEdge(TreeEdge):
             bindings = "{%s}" % ", ".join(
                 "%s: %r" % item for item in sorted(self._bindings.items())
             )
-            return "%s %s" % (super().__str__(), bindings)
+            return f"{super().__str__()} {bindings}"
 
 
 # ////////////////////////////////////////////////////////////
@@ -237,8 +236,7 @@ class FeatureChart(Chart):
                 and (edge.lhs()[TYPE] == start[TYPE])
                 and (unify(edge.lhs(), start, rename_vars=True))
             ):
-                for tree in self.trees(edge, complete=True, tree_class=tree_class):
-                    yield tree
+                yield from self.trees(edge, complete=True, tree_class=tree_class)
 
 
 # ////////////////////////////////////////////////////////////
@@ -250,7 +248,7 @@ class FeatureFundamentalRule(FundamentalRule):
     r"""
     A specialized version of the fundamental rule that operates on
     nonterminals whose symbols are ``FeatStructNonterminal``s.  Rather
-    tha simply comparing the nonterminals for equality, they are
+    than simply comparing the nonterminals for equality, they are
     unified.  Variable bindings from these unifications are collected
     and stored in the chart using a ``FeatureTreeEdge``.  When a
     complete edge is generated, these bindings are applied to all
@@ -323,16 +321,14 @@ class FeatureSingleEdgeFundamentalRule(SingleEdgeFundamentalRule):
         for left_edge in chart.select(
             end=right_edge.start(), is_complete=False, nextsym=right_edge.lhs()
         ):
-            for new_edge in fr.apply(chart, grammar, left_edge, right_edge):
-                yield new_edge
+            yield from fr.apply(chart, grammar, left_edge, right_edge)
 
     def _apply_incomplete(self, chart, grammar, left_edge):
         fr = self._fundamental_rule
         for right_edge in chart.select(
             start=left_edge.end(), is_complete=True, lhs=left_edge.nextsym()
         ):
-            for new_edge in fr.apply(chart, grammar, left_edge, right_edge):
-                yield new_edge
+            yield from fr.apply(chart, grammar, left_edge, right_edge)
 
 
 # ////////////////////////////////////////////////////////////
@@ -494,7 +490,7 @@ class FeatureChartParser(ChartParser):
         strategy=BU_LC_FEATURE_STRATEGY,
         trace_chart_width=20,
         chart_class=FeatureChart,
-        **parser_args
+        **parser_args,
     ):
         ChartParser.__init__(
             self,
@@ -502,7 +498,7 @@ class FeatureChartParser(ChartParser):
             strategy=strategy,
             trace_chart_width=trace_chart_width,
             chart_class=chart_class,
-            **parser_args
+            **parser_args,
         )
 
 
@@ -580,11 +576,11 @@ class InstantiateVarsChart(FeatureChart):
         edge._lhs = edge.lhs().substitute_bindings(inst_vars)
 
     def inst_vars(self, edge):
-        return dict(
-            (var, logic.unique_variable())
+        return {
+            var: logic.unique_variable()
             for var in edge.lhs().variables()
             if var.name.startswith("@")
-        )
+        }
 
 
 # ////////////////////////////////////////////////////////////
@@ -628,7 +624,8 @@ def demo(
     parser=FeatureChartParser,
     sent="I saw John with a dog with my cookie",
 ):
-    import sys, time
+    import sys
+    import time
 
     print()
     grammar = demo_grammar()
