@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Generating from a CFG
 #
 # Copyright (C) 2001-2021 NLTK Project
@@ -10,6 +9,7 @@
 
 import itertools
 import sys
+
 from nltk.grammar import Nonterminal
 
 
@@ -58,8 +58,7 @@ def _generate_one(grammar, item, depth):
     if depth > 0:
         if isinstance(item, Nonterminal):
             for prod in grammar.productions(lhs=item):
-                for frag in _generate_all(grammar, prod.rhs(), depth - 1):
-                    yield frag
+                yield from _generate_all(grammar, prod.rhs(), depth - 1)
         else:
             yield [item]
 
