@@ -7,8 +7,8 @@
 # For license information, see LICENSE.TXT
 #
 
-import math
 import logging
+import math
 
 from nltk.parse.dependencygraph import DependencyGraph
 
@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 #################################################################
 
 
-class DependencyScorerI(object):
+class DependencyScorerI:
     """
     A scorer for calculated the weights on the edges of a weighted
     dependency graph.  This is used by a
@@ -150,13 +150,11 @@ class NaiveBayesDependencyScorer(DependencyScorerI):
         for head_node in graph.nodes.values():
             for child_node in graph.nodes.values():
                 edges.append(
-                    (
-                        dict(
-                            a=head_node["word"],
-                            b=head_node["tag"],
-                            c=child_node["word"],
-                            d=child_node["tag"],
-                        )
+                    dict(
+                        a=head_node["word"],
+                        b=head_node["tag"],
+                        c=child_node["word"],
+                        d=child_node["tag"],
                     )
                 )
 
@@ -199,7 +197,7 @@ class DemoScorer(DependencyScorerI):
 #################################################################
 
 
-class ProbabilisticNonprojectiveParser(object):
+class ProbabilisticNonprojectiveParser:
     """A probabilistic non-projective dependency parser.
 
     Nonprojective dependencies allows for "crossing branches" in the parse tree
@@ -559,7 +557,7 @@ class ProbabilisticNonprojectiveParser(object):
 #################################################################
 
 
-class NonprojectiveDependencyParser(object):
+class NonprojectiveDependencyParser:
     """
     A non-projective, rule-based, dependency parser.  This parser
     will return the set of all possible non-projective parses based on
