@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Dependency Grammars
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Jason Narad <jason.narad@gmail.com>
 #
 # URL: <http://nltk.org/>
@@ -8,17 +8,16 @@
 #
 
 from collections import defaultdict
-from itertools import chain
 from functools import total_ordering
+from itertools import chain
 
 from nltk.grammar import (
-    DependencyProduction,
     DependencyGrammar,
+    DependencyProduction,
     ProbabilisticDependencyGrammar,
 )
-from nltk.parse.dependencygraph import DependencyGraph
 from nltk.internals import raise_unorderable_types
-
+from nltk.parse.dependencygraph import DependencyGraph
 
 #################################################################
 # Dependency Span
@@ -26,7 +25,7 @@ from nltk.internals import raise_unorderable_types
 
 
 @total_ordering
-class DependencySpan(object):
+class DependencySpan:
     """
     A contiguous span over some part of the input string representing
     dependency (head -> modifier) relationships amongst words.  An atomic
@@ -104,7 +103,7 @@ class DependencySpan(object):
 #################################################################
 
 
-class ChartCell(object):
+class ChartCell:
     """
     A cell from the parse chart formed when performing the CYK algorithm.
     Each cell keeps track of its x and y coordinates (though this will probably
@@ -120,7 +119,7 @@ class ChartCell(object):
         """
         self._x = x
         self._y = y
-        self._entries = set([])
+        self._entries = set()
 
     def add(self, span):
         """
@@ -152,7 +151,7 @@ class ChartCell(object):
 #################################################################
 
 
-class ProjectiveDependencyParser(object):
+class ProjectiveDependencyParser:
     """
     A projective, rule-based, dependency parser.  A ProjectiveDependencyParser
     is created with a DependencyGrammar, a set of productions specifying
@@ -285,7 +284,7 @@ class ProjectiveDependencyParser(object):
 #################################################################
 
 
-class ProbabilisticProjectiveDependencyParser(object):
+class ProbabilisticProjectiveDependencyParser:
     """A probabilistic, projective dependency parser.
 
     This parser returns the most probable projective parse derived from the
@@ -453,7 +452,9 @@ class ProbabilisticProjectiveDependencyParser(object):
         for dg in graphs:
             for node_index in range(1, len(dg.nodes)):
                 # children = dg.nodes[node_index]['deps']
-                children = list(chain(*dg.nodes[node_index]["deps"].values()))
+                children = list(
+                    chain.from_iterable(dg.nodes[node_index]["deps"].values())
+                )
 
                 nr_left_children = dg.left_children(node_index)
                 nr_right_children = dg.right_children(node_index)
@@ -466,7 +467,7 @@ class ProbabilisticProjectiveDependencyParser(object):
                     if head_word in tags:
                         tags[head_word].add(head_tag)
                     else:
-                        tags[head_word] = set([head_tag])
+                        tags[head_word] = {head_tag}
                     child = "STOP"
                     child_tag = "STOP"
                     prev_word = "START"
@@ -481,14 +482,14 @@ class ProbabilisticProjectiveDependencyParser(object):
                             prev_tag = dg.nodes[children[array_index + 1]]["tag"]
                         if child != "STOP":
                             productions.append(DependencyProduction(head_word, [child]))
-                        head_event = "(head (%s %s) (mods (%s, %s, %s) left))" % (
+                        head_event = "(head ({} {}) (mods ({}, {}, {}) left))".format(
                             child,
                             child_tag,
                             prev_tag,
                             head_word,
                             head_tag,
                         )
-                        mod_event = "(mods (%s, %s, %s) left))" % (
+                        mod_event = "(mods ({}, {}, {}) left))".format(
                             prev_tag,
                             head_word,
                             head_tag,
@@ -505,14 +506,14 @@ class ProbabilisticProjectiveDependencyParser(object):
                             prev_tag = dg.nodes[children[array_index - 1]]["tag"]
                         if child != "STOP":
                             productions.append(DependencyProduction(head_word, [child]))
-                        head_event = "(head (%s %s) (mods (%s, %s, %s) right))" % (
+                        head_event = "(head ({} {}) (mods ({}, {}, {}) right))".format(
                             child,
                             child_tag,
                             prev_tag,
                             head_word,
                             head_tag,
                         )
-                        mod_event = "(mods (%s, %s, %s) right))" % (
+                        mod_event = "(mods ({}, {}, {}) right))".format(
                             prev_tag,
                             head_word,
                             head_tag,
@@ -535,7 +536,7 @@ class ProbabilisticProjectiveDependencyParser(object):
         prob = 1.0
         for node_index in range(1, len(dg.nodes)):
             # children = dg.nodes[node_index]['deps']
-            children = list(chain(*dg.nodes[node_index]["deps"].values()))
+            children = list(chain.from_iterable(dg.nodes[node_index]["deps"].values()))
 
             nr_left_children = dg.left_children(node_index)
             nr_right_children = dg.right_children(node_index)
@@ -555,14 +556,14 @@ class ProbabilisticProjectiveDependencyParser(object):
                     if child_index != -1:
                         prev_word = dg.nodes[children[array_index + 1]]["word"]
                         prev_tag = dg.nodes[children[array_index + 1]]["tag"]
-                    head_event = "(head (%s %s) (mods (%s, %s, %s) left))" % (
+                    head_event = "(head ({} {}) (mods ({}, {}, {}) left))".format(
                         child,
                         child_tag,
                         prev_tag,
                         head_word,
                         head_tag,
                     )
-                    mod_event = "(mods (%s, %s, %s) left))" % (
+                    mod_event = "(mods ({}, {}, {}) left))".format(
                         prev_tag,
                         head_word,
                         head_tag,
@@ -584,14 +585,14 @@ class ProbabilisticProjectiveDependencyParser(object):
                     if child_index != 1:
                         prev_word = dg.nodes[children[array_index - 1]]["word"]
                         prev_tag = dg.nodes[children[array_index - 1]]["tag"]
-                    head_event = "(head (%s %s) (mods (%s, %s, %s) right))" % (
+                    head_event = "(head ({} {}) (mods ({}, {}, {}) right))".format(
                         child,
                         child_tag,
                         prev_tag,
                         head_word,
                         head_tag,
                     )
-                    mod_event = "(mods (%s, %s, %s) right))" % (
+                    mod_event = "(mods ({}, {}, {}) right))".format(
                         prev_tag,
                         head_word,
                         head_tag,
