@@ -123,9 +123,9 @@ current directory.
 
 """
 
+import os
 import re
 import shelve
-import os
 import sys
 
 import nltk.data
@@ -243,7 +243,7 @@ not_unary = ["borders.pl", "contain.pl"]
 ###########################################################################
 
 
-class Concept(object):
+class Concept:
     """
     A Concept class, loosely based on SKOS
     (http://www.w3.org/TR/swbp-skos-core-guide/).
@@ -280,7 +280,7 @@ class Concept(object):
         # _extension += element + ', '
         # _extension = _extension[:-1]
 
-        return "Label = '%s'\nArity = %s\nExtension = %s" % (
+        return "Label = '{}'\nArity = {}\nExtension = {}".format(
             self.prefLabel,
             self.arity,
             self.extension,
@@ -819,7 +819,7 @@ Valuation object for use in the NLTK semantics package.
             concepts = concept_map.values()
             # just print out the vocabulary
             if options.vocab:
-                items = sorted([(c.arity, c.prefLabel) for c in concepts])
+                items = sorted((c.arity, c.prefLabel) for c in concepts)
                 for (arity, label) in items:
                     print(label, arity)
                 sys.exit(0)
