@@ -8,31 +8,23 @@
 # For license information, see LICENSE.TXT
 
 try:
-    from tkinter import (
-        Button,
-        Frame,
-        IntVar,
-        Label,
-        Listbox,
-        Menu,
-        Scrollbar,
-        Tk,
-    )
+    from tkinter import Button, Frame, IntVar, Label, Listbox, Menu, Scrollbar, Tk
     from tkinter.font import Font
+
     from nltk.draw.util import CanvasFrame, ShowText
 
 except ImportError:
     """Ignore ImportError because tkinter might not be available."""
 
-from nltk.util import in_idle
-from nltk.tag import RegexpTagger
 from nltk.parse import MaltParser
-from nltk.sem.logic import Variable
 from nltk.sem.drt import DrsDrawer, DrtVariableExpression
 from nltk.sem.glue import DrtGlue
+from nltk.sem.logic import Variable
+from nltk.tag import RegexpTagger
+from nltk.util import in_idle
 
 
-class DrtGlueDemo(object):
+class DrtGlueDemo:
     def __init__(self, examples):
         # Set up the main window.
         self._top = Tk()
@@ -513,7 +505,7 @@ class DrtGlueDemo(object):
             self._redraw()
 
 
-class DrsWidget(object):
+class DrsWidget:
     def __init__(self, canvas, drs, **attribs):
         self._drs = drs
         self._canvas = canvas
