@@ -11,16 +11,15 @@ from itertools import chain
 
 import nltk
 from nltk.internals import Counter
-from nltk.tag import UnigramTagger, BigramTagger, TrigramTagger, RegexpTagger
+from nltk.sem import drt, linearlogic
 from nltk.sem.logic import (
+    AbstractVariableExpression,
     Expression,
+    LambdaExpression,
     Variable,
     VariableExpression,
-    LambdaExpression,
-    AbstractVariableExpression,
 )
-from nltk.sem import drt
-from nltk.sem import linearlogic
+from nltk.tag import BigramTagger, RegexpTagger, TrigramTagger, UnigramTagger
 
 SPEC_SEMTYPES = {
     "a": "ex_quant",
@@ -34,7 +33,7 @@ SPEC_SEMTYPES = {
 OPTIONAL_RELATIONSHIPS = ["nmod", "vmod", "punct"]
 
 
-class GlueFormula(object):
+class GlueFormula:
     def __init__(self, meaning, glue, indices=None):
         if not indices:
             indices = set()
@@ -62,13 +61,13 @@ class GlueFormula(object):
         self.indices = indices
 
     def applyto(self, arg):
-        """ self = (\\x.(walk x), (subj -o f))
-            arg  = (john        ,  subj)
-            returns ((walk john),          f)
+        """self = (\\x.(walk x), (subj -o f))
+        arg  = (john        ,  subj)
+        returns ((walk john),          f)
         """
         if self.indices & arg.indices:  # if the sets are NOT disjoint
             raise linearlogic.LinearLogicApplicationException(
-                "'%s' applied to '%s'.  Indices are not disjoint." % (self, arg)
+                f"'{self}' applied to '{arg}'.  Indices are not disjoint."
             )
         else:  # if the sets ARE disjoint
             return_indices = self.indices | arg.indices
@@ -79,7 +78,7 @@ class GlueFormula(object):
             )
         except linearlogic.LinearLogicApplicationException as e:
             raise linearlogic.LinearLogicApplicationException(
-                "'%s' applied to '%s'" % (self.simplify(), arg.simplify())
+                f"'{self.simplify()}' applied to '{arg.simplify()}'"
             ) from e
 
         arg_meaning_abstracted = arg.meaning
@@ -116,7 +115,7 @@ class GlueFormula(object):
             counter, self.__class__
         )
         return new_forms + [
-            self.__class__(self.meaning, compiled_glue, set([counter.get()]))
+            self.__class__(self.meaning, compiled_glue, {counter.get()})
         ]
 
     def simplify(self):
@@ -140,9 +139,11 @@ class GlueFormula(object):
 
     def __str__(self):
         assert isinstance(self.indices, set)
-        accum = "%s : %s" % (self.meaning, self.glue)
+        accum = f"{self.meaning} : {self.glue}"
         if self.indices:
-            accum += " : {" + ", ".join(str(index) for index in sorted(self.indices)) + "}"
+            accum += (
+                " : {" + ", ".join(str(index) for index in sorted(self.indices)) + "}"
+            )
         return accum
 
     def __repr__(self):
@@ -359,7 +360,7 @@ class GlueDict(dict):
             # most relations of any possible relationship set that is a subset
             # of the actual depgraph
             best_match = frozenset()
-            for relset_option in set(semtype) - set([None]):
+            for relset_option in set(semtype) - {None}:
                 if (
                     len(relset_option) > len(best_match)
                     and relset_option < relationships
@@ -403,7 +404,7 @@ class GlueDict(dict):
             if not len(glueformulas):
                 gf.word = word
             else:
-                gf.word = "%s%s" % (word, len(glueformulas) + 1)
+                gf.word = f"{word}{len(glueformulas) + 1}"
 
             gf.glue = self.initialize_labels(gf.glue, node, depgraph, counter.get())
 
@@ -460,7 +461,7 @@ class GlueDict(dict):
             elif name == "super":
                 return self.get_label(depgraph.nodes[node["head"]])
             elif name == "var":
-                return "%s%s" % (lbl.upper(), unique_index)
+                return f"{lbl.upper()}{unique_index}"
             elif name == "a":
                 return self.get_label(self.lookup_unique("conja", node, depgraph))
             elif name == "b":
@@ -522,10 +523,12 @@ class GlueDict(dict):
         ]
 
         if len(deps) == 0:
-            raise KeyError("'%s' doesn't contain a feature '%s'" % (node["word"], rel))
+            raise KeyError(
+                "'{}' doesn't contain a feature '{}'".format(node["word"], rel)
+            )
         elif len(deps) > 1:
             raise KeyError(
-                "'%s' should only have one feature '%s'" % (node["word"], rel)
+                "'{}' should only have one feature '{}'".format(node["word"], rel)
             )
         else:
             return deps[0]
@@ -534,7 +537,7 @@ class GlueDict(dict):
         return GlueFormula
 
 
-class Glue(object):
+class Glue:
     def __init__(
         self, semtype_file=None, remove_duplicates=False, depparser=None, verbose=False
     ):
@@ -822,7 +825,7 @@ def demo(show_example=-1):
 
     for (i, sentence) in enumerate(examples):
         if i == show_example or show_example == -1:
-            print("[[[Example %s]]]  %s" % (i, sentence))
+            print(f"[[[Example {i}]]]  {sentence}")
             for reading in glue.parse_to_meaning(sentence.split()):
                 print(reading.simplify())
             print("")
