@@ -23,8 +23,6 @@ convert that representation into first-order logic formulas.
 from functools import reduce
 
 from nltk.parse import load_parser
-
-from nltk.sem.skolemize import skolemize
 from nltk.sem.logic import (
     AllExpression,
     AndExpression,
@@ -36,7 +34,7 @@ from nltk.sem.logic import (
     NegatedExpression,
     OrExpression,
 )
-
+from nltk.sem.skolemize import skolemize
 
 # Note that in this code there may be multiple types of trees being referred to:
 #
@@ -47,7 +45,7 @@ from nltk.sem.logic import (
 #
 
 
-class Constants(object):
+class Constants:
     ALL = "ALL"
     EXISTS = "EXISTS"
     NOT = "NOT"
@@ -72,7 +70,7 @@ class Constants(object):
     }
 
 
-class HoleSemantics(object):
+class HoleSemantics:
     """
     This class holds the broken-down components of a hole semantics, i.e. it
     extracts the holes, labels, logic formula fragments and constraints out of
@@ -298,7 +296,7 @@ class HoleSemantics(object):
             return node
 
 
-class Constraint(object):
+class Constraint:
     """
     This class represents a constraint of the form (L =< N),
     where L is a label and N is a node (a label or a hole).
@@ -321,7 +319,7 @@ class Constraint(object):
         return hash(repr(self))
 
     def __repr__(self):
-        return "(%s < %s)" % (self.lhs, self.rhs)
+        return f"({self.lhs} < {self.rhs})"
 
 
 def hole_readings(sentence, grammar_filename=None, verbose=False):
@@ -369,7 +367,7 @@ def hole_readings(sentence, grammar_filename=None, verbose=False):
             print("Top labels:  ", hole_sem.top_most_labels)
             print("Fragments:")
             for l, f in hole_sem.fragments.items():
-                print("\t%s: %s" % (l, f))
+                print(f"\t{l}: {f}")
 
         # Find all the possible ways to plug the formulas together.
         pluggings = hole_sem.pluggings()
