@@ -18,16 +18,14 @@ consulted instead.  Any SequentialBackoffTagger may serve as a
 backoff tagger for any other SequentialBackoffTagger.
 """
 import ast
-from abc import abstractmethod
-
 import re
-
-from nltk.probability import ConditionalFreqDist
-from nltk.classify import NaiveBayesClassifier
-
-from nltk.tag.api import TaggerI, FeaturesetTaggerI
+from abc import abstractmethod
+from typing import List, Optional, Tuple
 
 from nltk import jsontags
+from nltk.classify import NaiveBayesClassifier
+from nltk.probability import ConditionalFreqDist
+from nltk.tag.api import FeaturesetTaggerI, TaggerI
 
 
 ######################################################################
@@ -149,7 +147,7 @@ class ContextTagger(SequentialBackoffTagger):
         return len(self._context_to_tag)
 
     def __repr__(self):
-        return "<{}: size={}>".format(self.__class__.__name__, self.size())
+        return f"<{self.__class__.__name__}: size={self.size()}>"
 
     def _train(self, tagged_corpus, cutoff=0, verbose=False):
         """
@@ -208,7 +206,11 @@ class ContextTagger(SequentialBackoffTagger):
             backoff = 100 - (hit_count * 100.0) / token_count
             pruning = 100 - (size * 100.0) / len(fd.conditions())
             print("[Trained Unigram tagger:", end=" ")
-            print("size={}, backoff={:.2f}%, pruning={:.2f}%]".format(size, backoff, pruning))
+            print(
+                "size={}, backoff={:.2f}%, pruning={:.2f}%]".format(
+                    size, backoff, pruning
+                )
+            )
 
 
 ######################################################################
@@ -252,7 +254,7 @@ class DefaultTagger(SequentialBackoffTagger):
         return self._tag  # ignore token and history
 
     def __repr__(self):
-        return "<DefaultTagger: tag={}>".format(self._tag)
+        return f"<DefaultTagger: tag={self._tag}>"
 
 
 @jsontags.register_tag
@@ -524,7 +526,7 @@ class RegexpTagger(SequentialBackoffTagger):
     :type regexps: list(tuple(str, str))
     :param regexps: A list of ``(regexp, tag)`` pairs, each of
         which indicates that a word matching ``regexp`` should
-        be tagged with ``tag``.  The pairs will be evalutated in
+        be tagged with ``tag``.  The pairs will be evaluated in
         order.  If none of the regexps match a word, then the
         optional backoff tagger is invoked, else it is
         assigned the tag None.
@@ -532,16 +534,18 @@ class RegexpTagger(SequentialBackoffTagger):
 
     json_tag = "nltk.tag.sequential.RegexpTagger"
 
-    def __init__(self, regexps, backoff=None):
-        """
-        """
+    def __init__(
+        self, regexps: List[Tuple[str, str]], backoff: Optional[TaggerI] = None
+    ):
         super().__init__(backoff)
-        try:
-            self._regexps = [(re.compile(regexp), tag,) for regexp, tag in regexps]
-        except Exception as e:
-            raise Exception(
-                'Invalid RegexpTagger regexp:', str(e), 'regexp:', regexp, 'tag:', tag
-            ) from e
+        self._regexps = []
+        for regexp, tag in regexps:
+            try:
+                self._regexps.append((re.compile(regexp), tag))
+            except Exception as e:
+                raise Exception(
+                    f"Invalid RegexpTagger regexp: {e}\n- regexp: {regexp!r}\n- tag: {tag!r}"
+                ) from e
 
     def encode_json_obj(self):
         return [(regexp.pattern, tag) for regexp, tag in self._regexps], self.backoff
@@ -558,7 +562,7 @@ class RegexpTagger(SequentialBackoffTagger):
         return None
 
     def __repr__(self):
-        return "<Regexp Tagger: size={}>".format(len(self._regexps))
+        return f"<Regexp Tagger: size={len(self._regexps)}>"
 
 
 class ClassifierBasedTagger(SequentialBackoffTagger, FeaturesetTaggerI):
@@ -671,11 +675,11 @@ class ClassifierBasedTagger(SequentialBackoffTagger, FeaturesetTaggerI):
                 history.append(tags[index])
 
         if verbose:
-            print("Training classifier ({} instances)".format(len(classifier_corpus)))
+            print(f"Training classifier ({len(classifier_corpus)} instances)")
         self._classifier = classifier_builder(classifier_corpus)
 
     def __repr__(self):
-        return "<ClassifierBasedTagger: {}>".format(self._classifier)
+        return f"<ClassifierBasedTagger: {self._classifier}>"
 
     def feature_detector(self, tokens, index, history):
         """
@@ -743,9 +747,9 @@ class ClassifierBasedPOSTagger(ClassifierBasedTagger):
             "suffix1": word.lower()[-1:],
             "prevprevword": prevprevword,
             "prevword": prevword,
-            "prevtag+word": "{}+{}".format(prevtag, word.lower()),
-            "prevprevtag+word": "{}+{}".format(prevprevtag, word.lower()),
-            "prevword+word": "{}+{}".format(prevword, word.lower()),
+            "prevtag+word": f"{prevtag}+{word.lower()}",
+            "prevprevtag+word": f"{prevprevtag}+{word.lower()}",
+            "prevword+word": f"{prevword}+{word.lower()}",
             "shape": shape,
         }
         return features
