@@ -5,9 +5,10 @@
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-import pytest
 import unittest
 
+import pytest
+
 from nltk import FreqDist
 from nltk.lm import NgramCounter
 from nltk.util import everygrams
@@ -20,11 +21,9 @@ class TestNgramCounter:
     def setup_class(self):
         text = [list("abcd"), list("egdbe")]
         self.trigram_counter = NgramCounter(
-            (everygrams(sent, max_len=3) for sent in text)
-        )
-        self.bigram_counter = NgramCounter(
-            (everygrams(sent, max_len=2) for sent in text)
+            everygrams(sent, max_len=3) for sent in text
         )
+        self.bigram_counter = NgramCounter(everygrams(sent, max_len=2) for sent in text)
         self.case = unittest.TestCase()
 
     def test_N(self):
