@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Tests for BLEU translation evaluation metric
 """
@@ -8,11 +7,13 @@ import unittest
 
 from nltk.data import find
 from nltk.translate.bleu_score import (
-    modified_precision,
+    SmoothingFunction,
     brevity_penalty,
     closest_ref_length,
+    corpus_bleu,
+    modified_precision,
+    sentence_bleu,
 )
-from nltk.translate.bleu_score import sentence_bleu, corpus_bleu, SmoothingFunction
 
 
 class TestBLEU(unittest.TestCase):
@@ -23,10 +24,10 @@ class TestBLEU(unittest.TestCase):
         """
         # Example 1: the "the*" example.
         # Reference sentences.
-        ref1 = 'the cat is on the mat'.split()
-        ref2 = 'there is a cat on the mat'.split()
+        ref1 = "the cat is on the mat".split()
+        ref2 = "there is a cat on the mat".split()
         # Hypothesis sentence(s).
-        hyp1 = 'the the the the the the the'.split()
+        hyp1 = "the the the the the the the".split()
 
         references = [ref1, ref2]
 
@@ -42,19 +43,19 @@ class TestBLEU(unittest.TestCase):
         # Example 2: the "of the" example.
         # Reference sentences
         ref1 = str(
-            'It is a guide to action that ensures that the military '
-            'will forever heed Party commands'
+            "It is a guide to action that ensures that the military "
+            "will forever heed Party commands"
         ).split()
         ref2 = str(
-            'It is the guiding principle which guarantees the military '
-            'forces always being under the command of the Party'
+            "It is the guiding principle which guarantees the military "
+            "forces always being under the command of the Party"
         ).split()
         ref3 = str(
-            'It is the practical guide for the army always to heed '
-            'the directions of the party'
+            "It is the practical guide for the army always to heed "
+            "the directions of the party"
         ).split()
         # Hypothesis sentence(s).
-        hyp1 = 'of the'.split()
+        hyp1 = "of the".split()
 
         references = [ref1, ref2, ref3]
         # Testing modified unigram precision.
@@ -65,12 +66,12 @@ class TestBLEU(unittest.TestCase):
 
         # Example 3: Proper MT outputs.
         hyp1 = str(
-            'It is a guide to action which ensures that the military '
-            'always obeys the commands of the party'
+            "It is a guide to action which ensures that the military "
+            "always obeys the commands of the party"
         ).split()
         hyp2 = str(
-            'It is to insure the troops forever hearing the activity '
-            'guidebook that party direct'
+            "It is to insure the troops forever hearing the activity "
+            "guidebook that party direct"
         ).split()
 
         references = [ref1, ref2, ref3]
@@ -98,24 +99,24 @@ class TestBLEU(unittest.TestCase):
     def test_brevity_penalty(self):
         # Test case from brevity_penalty_closest function in mteval-v13a.pl.
         # Same test cases as in the doctest in nltk.translate.bleu_score.py
-        references = [['a'] * 11, ['a'] * 8]
-        hypothesis = ['a'] * 7
+        references = [["a"] * 11, ["a"] * 8]
+        hypothesis = ["a"] * 7
         hyp_len = len(hypothesis)
         closest_ref_len = closest_ref_length(references, hyp_len)
         self.assertAlmostEqual(
             brevity_penalty(closest_ref_len, hyp_len), 0.8669, places=4
         )
 
-        references = [['a'] * 11, ['a'] * 8, ['a'] * 6, ['a'] * 7]
-        hypothesis = ['a'] * 7
+        references = [["a"] * 11, ["a"] * 8, ["a"] * 6, ["a"] * 7]
+        hypothesis = ["a"] * 7
         hyp_len = len(hypothesis)
         closest_ref_len = closest_ref_length(references, hyp_len)
         assert brevity_penalty(closest_ref_len, hyp_len) == 1.0
 
     def test_zero_matches(self):
         # Test case where there's 0 matches
-        references = ['The candidate has no alignment to any of the references'.split()]
-        hypothesis = 'John loves Mary'.split()
+        references = ["The candidate has no alignment to any of the references".split()]
+        hypothesis = "John loves Mary".split()
 
         # Test BLEU to nth order of n-grams, where n is len(hypothesis).
         for n in range(1, len(hypothesis)):
@@ -124,8 +125,8 @@ class TestBLEU(unittest.TestCase):
 
     def test_full_matches(self):
         # Test case where there's 100% matches
-        references = ['John loves Mary'.split()]
-        hypothesis = 'John loves Mary'.split()
+        references = ["John loves Mary".split()]
+        hypothesis = "John loves Mary".split()
 
         # Test BLEU to nth order of n-grams, where n is len(hypothesis).
         for n in range(1, len(hypothesis)):
@@ -133,8 +134,8 @@ class TestBLEU(unittest.TestCase):
             assert sentence_bleu(references, hypothesis, weights) == 1.0
 
     def test_partial_matches_hypothesis_longer_than_reference(self):
-        references = ['John loves Mary'.split()]
-        hypothesis = 'John loves Mary who loves Mike'.split()
+        references = ["John loves Mary".split()]
+        hypothesis = "John loves Mary who loves Mike".split()
         # Since no 4-grams matches were found the result should be zero
         # exp(w_1 * 1 * w_2 * 1 * w_3 * 1 * w_4 * -inf) = 0
         self.assertAlmostEqual(sentence_bleu(references, hypothesis), 0.0, places=4)
@@ -149,8 +150,8 @@ class TestBLEU(unittest.TestCase):
 class TestBLEUFringeCases(unittest.TestCase):
     def test_case_where_n_is_bigger_than_hypothesis_length(self):
         # Test BLEU to nth order of n-grams, where n > len(hypothesis).
-        references = ['John loves Mary ?'.split()]
-        hypothesis = 'John loves Mary'.split()
+        references = ["John loves Mary ?".split()]
+        hypothesis = "John loves Mary".split()
         n = len(hypothesis) + 1  #
         weights = [1.0 / n] * n  # Uniform weights.
         # Since no n-grams matches were found the result should be zero
@@ -166,8 +167,8 @@ class TestBLEUFringeCases(unittest.TestCase):
 
         # Test case where n > len(hypothesis) but so is n > len(reference), and
         # it's a special case where reference == hypothesis.
-        references = ['John loves Mary'.split()]
-        hypothesis = 'John loves Mary'.split()
+        references = ["John loves Mary".split()]
+        hypothesis = "John loves Mary".split()
         # Since no 4-grams matches were found the result should be zero
         # exp(w_1 * 1 * w_2 * 1 * w_3 * 1 * w_4 * -inf) = 0
         self.assertAlmostEqual(
@@ -176,14 +177,14 @@ class TestBLEUFringeCases(unittest.TestCase):
 
     def test_empty_hypothesis(self):
         # Test case where there's hypothesis is empty.
-        references = ['The candidate has no alignment to any of the references'.split()]
+        references = ["The candidate has no alignment to any of the references".split()]
         hypothesis = []
         assert sentence_bleu(references, hypothesis) == 0
 
     def test_empty_references(self):
         # Test case where there's reference is empty.
         references = [[]]
-        hypothesis = 'John loves Mary'.split()
+        hypothesis = "John loves Mary".split()
         assert sentence_bleu(references, hypothesis) == 0
 
     def test_empty_references_and_hypothesis(self):
@@ -193,10 +194,10 @@ class TestBLEUFringeCases(unittest.TestCase):
         assert sentence_bleu(references, hypothesis) == 0
 
     def test_reference_or_hypothesis_shorter_than_fourgrams(self):
-        # Tese case where the length of reference or hypothesis
+        # Test case where the length of reference or hypothesis
         # is shorter than 4.
-        references = ['let it go'.split()]
-        hypothesis = 'let go it'.split()
+        references = ["let it go".split()]
+        hypothesis = "let go it".split()
         # Checks that the value the hypothesis and reference returns is 0.0
         # exp(w_1 * 1 * w_2 * 1 * w_3 * 1 * w_4 * -inf) = 0
         self.assertAlmostEqual(sentence_bleu(references, hypothesis), 0.0, places=4)
@@ -209,19 +210,19 @@ class TestBLEUFringeCases(unittest.TestCase):
 
 class TestBLEUvsMteval13a(unittest.TestCase):
     def test_corpus_bleu(self):
-        ref_file = find('models/wmt15_eval/ref.ru')
-        hyp_file = find('models/wmt15_eval/google.ru')
-        mteval_output_file = find('models/wmt15_eval/mteval-13a.output')
+        ref_file = find("models/wmt15_eval/ref.ru")
+        hyp_file = find("models/wmt15_eval/google.ru")
+        mteval_output_file = find("models/wmt15_eval/mteval-13a.output")
 
         # Reads the BLEU scores from the `mteval-13a.output` file.
         # The order of the list corresponds to the order of the ngrams.
-        with open(mteval_output_file, 'r') as mteval_fin:
+        with open(mteval_output_file) as mteval_fin:
             # The numbers are located in the last 2nd line of the file.
             # The first and 2nd item in the list are the score and system names.
             mteval_bleu_scores = map(float, mteval_fin.readlines()[-2].split()[1:-1])
 
-        with io.open(ref_file, 'r', encoding='utf8') as ref_fin:
-            with io.open(hyp_file, 'r', encoding='utf8') as hyp_fin:
+        with open(ref_file, encoding="utf8") as ref_fin:
+            with open(hyp_file, encoding="utf8") as hyp_fin:
                 # Whitespace tokenize the file.
                 # Note: split() automatically strip().
                 hypothesis = list(map(lambda x: x.split(), hyp_fin))
