@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Tokenizers
 #
 # Copyright (C) 2001-2021 NLTK Project
@@ -64,33 +63,33 @@ import re
 
 from nltk.data import load
 from nltk.tokenize.casual import TweetTokenizer, casual_tokenize
-from nltk.tokenize.mwe import MWETokenizer
 from nltk.tokenize.destructive import NLTKWordTokenizer
+from nltk.tokenize.legality_principle import LegalitySyllableTokenizer
+from nltk.tokenize.mwe import MWETokenizer
 from nltk.tokenize.punkt import PunktSentenceTokenizer
 from nltk.tokenize.regexp import (
+    BlanklineTokenizer,
     RegexpTokenizer,
     WhitespaceTokenizer,
-    BlanklineTokenizer,
     WordPunctTokenizer,
-    wordpunct_tokenize,
-    regexp_tokenize,
     blankline_tokenize,
+    regexp_tokenize,
+    wordpunct_tokenize,
 )
 from nltk.tokenize.repp import ReppTokenizer
 from nltk.tokenize.sexpr import SExprTokenizer, sexpr_tokenize
 from nltk.tokenize.simple import (
+    LineTokenizer,
     SpaceTokenizer,
     TabTokenizer,
-    LineTokenizer,
     line_tokenize,
 )
+from nltk.tokenize.sonority_sequencing import SyllableTokenizer
+from nltk.tokenize.stanford_segmenter import StanfordSegmenter
 from nltk.tokenize.texttiling import TextTilingTokenizer
 from nltk.tokenize.toktok import ToktokTokenizer
 from nltk.tokenize.treebank import TreebankWordTokenizer
-from nltk.tokenize.util import string_span_tokenize, regexp_span_tokenize
-from nltk.tokenize.stanford_segmenter import StanfordSegmenter
-from nltk.tokenize.sonority_sequencing import SyllableTokenizer
-from nltk.tokenize.legality_principle import LegalitySyllableTokenizer
+from nltk.tokenize.util import regexp_span_tokenize, string_span_tokenize
 
 
 # Standard sentence tokenizer.
@@ -104,7 +103,7 @@ def sent_tokenize(text, language="english"):
     :param text: text to split into sentences
     :param language: the model name in the Punkt corpus
     """
-    tokenizer = load("tokenizers/punkt/{0}.pickle".format(language))
+    tokenizer = load(f"tokenizers/punkt/{language}.pickle")
     return tokenizer.tokenize(text)
 
 
@@ -124,7 +123,7 @@ def word_tokenize(text, language="english", preserve_line=False):
     :type text: str
     :param language: the model name in the Punkt corpus
     :type language: str
-    :param preserve_line: An option to keep the preserve the sentence and not sentence tokenize it.
+    :param preserve_line: A flag to decide whether to sentence tokenize the text or not.
     :type preserve_line: bool
     """
     sentences = [text] if preserve_line else sent_tokenize(text, language)
