@@ -104,8 +104,8 @@ The algorithm for this tokenizer is described in::
 # TODO: Frequent sentence starters optionally exclude always-capitalised words
 # FIXME: Problem with ending string with e.g. '!!!' -> '!! !'
 
-import re
 import math
+import re
 from collections import defaultdict
 
 from nltk.probability import FreqDist
@@ -179,7 +179,7 @@ REASON_INITIAL_WITH_SPECIAL_ORTHOGRAPHIC_HEURISTIC = (
 ######################################################################
 
 
-class PunktLanguageVars(object):
+class PunktLanguageVars:
     """
     Stores variables, mostly regular expressions, which may be
     language-dependent for correct application of the algorithm.
@@ -220,7 +220,10 @@ class PunktLanguageVars(object):
 
     @property
     def _re_non_word_chars(self):
-        return "(?:[)\";}\]\*:@\'\({\[%s])" % re.escape("".join(set(self.sent_end_chars) - {"."}))
+        return r"(?:[)\";}\]\*:@\'\({\[%s])" % re.escape(
+            "".join(set(self.sent_end_chars) - {"."})
+        )
+
     """Characters that cannot appear within words"""
 
     _re_multi_char_punct = r"(?:\-{2,}|\.{2,}|(?:\.\s){2,}\.)"
@@ -305,18 +308,18 @@ numeric tokens are changed to ##number## and hence contain alpha.)"""
 # ////////////////////////////////////////////////////////////
 
 
-def _pair_iter(it):
+def _pair_iter(iterator):
     """
     Yields pairs of tokens from the given iterator such that each input
     token will appear as the first element in a yielded tuple. The last
     pair will have None as its second element.
     """
-    it = iter(it)
+    iterator = iter(iterator)
     try:
-        prev = next(it)
+        prev = next(iterator)
     except StopIteration:
         return
-    for el in it:
+    for el in iterator:
         yield (prev, el)
         prev = el
     yield (prev, None)
@@ -327,7 +330,7 @@ def _pair_iter(it):
 ######################################################################
 
 
-class PunktParameters(object):
+class PunktParameters:
     """Stores data used to perform sentence boundary detection with Punkt."""
 
     def __init__(self):
@@ -366,18 +369,18 @@ class PunktParameters(object):
         self.ortho_context[typ] |= flag
 
     def _debug_ortho_context(self, typ):
-        c = self.ortho_context[typ]
-        if c & _ORTHO_BEG_UC:
+        context = self.ortho_context[typ]
+        if context & _ORTHO_BEG_UC:
             yield "BEG-UC"
-        if c & _ORTHO_MID_UC:
+        if context & _ORTHO_MID_UC:
             yield "MID-UC"
-        if c & _ORTHO_UNK_UC:
+        if context & _ORTHO_UNK_UC:
             yield "UNK-UC"
-        if c & _ORTHO_BEG_LC:
+        if context & _ORTHO_BEG_LC:
             yield "BEG-LC"
-        if c & _ORTHO_MID_LC:
+        if context & _ORTHO_MID_LC:
             yield "MID-LC"
-        if c & _ORTHO_UNK_LC:
+        if context & _ORTHO_UNK_LC:
             yield "UNK-LC"
 
 
@@ -386,7 +389,7 @@ class PunktParameters(object):
 ######################################################################
 
 
-class PunktToken(object):
+class PunktToken:
     """Stores a token of text with annotations produced during
     sentence boundary detection."""
 
@@ -398,8 +401,8 @@ class PunktToken(object):
         self.type = self._get_type(tok)
         self.period_final = tok.endswith(".")
 
-        for p in self._properties:
-            setattr(self, p, None)
+        for prop in self._properties:
+            setattr(self, prop, None)
         for k in params:
             setattr(self, k, params[k])
 
@@ -453,7 +456,7 @@ class PunktToken(object):
     def first_case(self):
         if self.first_lower:
             return "lower"
-        elif self.first_upper:
+        if self.first_upper:
             return "upper"
         return "none"
 
@@ -495,12 +498,12 @@ class PunktToken(object):
         typestr = " type=%s," % repr(self.type) if self.type != self.tok else ""
 
         propvals = ", ".join(
-            "%s=%s" % (p, repr(getattr(self, p)))
+            f"{p}={repr(getattr(self, p))}"
             for p in self._properties
             if getattr(self, p)
         )
 
-        return "%s(%s,%s %s)" % (
+        return "{}({},{} {})".format(
             self.__class__.__name__,
             repr(self.tok),
             typestr,
@@ -526,7 +529,7 @@ class PunktToken(object):
 ######################################################################
 
 
-class PunktBaseClass(object):
+class PunktBaseClass:
     """
     Includes common components of PunktTrainer and PunktSentenceTokenizer.
     """
@@ -567,8 +570,8 @@ class PunktBaseClass(object):
                 yield self._Token(tok, parastart=parastart, linestart=True)
                 parastart = False
 
-                for t in line_toks:
-                    yield self._Token(t)
+                for tok in line_toks:
+                    yield self._Token(tok)
             else:
                 parastart = True
 
@@ -765,12 +768,12 @@ class PunktTrainer(PunktBaseClass):
                 if is_add:
                     self._params.abbrev_types.add(abbr)
                     if verbose:
-                        print(("  Abbreviation: [%6.4f] %s" % (score, abbr)))
+                        print(f"  Abbreviation: [{score:6.4f}] {abbr}")
             else:
                 if not is_add:
                     self._params.abbrev_types.remove(abbr)
                     if verbose:
-                        print(("  Removed abbreviation: [%6.4f] %s" % (score, abbr)))
+                        print(f"  Removed abbreviation: [{score:6.4f}] {abbr}")
 
         # Make a preliminary pass through the document, marking likely
         # sentence breaks, abbreviations, and ellipsis tokens.
@@ -793,7 +796,7 @@ class PunktTrainer(PunktBaseClass):
             if self._is_rare_abbrev_type(aug_tok1, aug_tok2):
                 self._params.abbrev_types.add(aug_tok1.type_no_period)
                 if verbose:
-                    print(("  Rare Abbrev: %s" % aug_tok1.type))
+                    print("  Rare Abbrev: %s" % aug_tok1.type)
 
             # Does second token have a high likelihood of starting a sentence?
             if self._is_potential_sent_starter(aug_tok2, aug_tok1):
@@ -806,7 +809,7 @@ class PunktTrainer(PunktBaseClass):
                 ] += 1
 
     def _unique_types(self, tokens):
-        return set(aug_tok.type for aug_tok in tokens)
+        return {aug_tok.type for aug_tok in tokens}
 
     def finalize_training(self, verbose=False):
         """
@@ -814,16 +817,16 @@ class PunktTrainer(PunktBaseClass):
         collocations and sentence starters.
         """
         self._params.clear_sent_starters()
-        for typ, ll in self._find_sent_starters():
+        for typ, log_likelihood in self._find_sent_starters():
             self._params.sent_starters.add(typ)
             if verbose:
-                print(("  Sent Starter: [%6.4f] %r" % (ll, typ)))
+                print(f"  Sent Starter: [{log_likelihood:6.4f}] {typ!r}")
 
         self._params.clear_collocations()
-        for (typ1, typ2), ll in self._find_collocations():
+        for (typ1, typ2), log_likelihood in self._find_collocations():
             self._params.collocations.add((typ1, typ2))
             if verbose:
-                print(("  Collocation: [%6.4f] %r+%r" % (ll, typ1, typ2)))
+                print(f"  Collocation: [{log_likelihood:6.4f}] {typ1!r}+{typ2!r}")
 
         self._finalized = True
 
@@ -968,11 +971,11 @@ class PunktTrainer(PunktBaseClass):
             # Let <a> be the candidate without the period, and <b>
             # be the period.  Find a log likelihood ratio that
             # indicates whether <ab> occurs as a single unit (high
-            # value of ll), or as two independent units <a> and
-            # <b> (low value of ll).
+            # value of log_likelihood), or as two independent units <a> and
+            # <b> (low value of log_likelihood).
             count_with_period = self._type_fdist[typ + "."]
             count_without_period = self._type_fdist[typ]
-            ll = self._dunning_log_likelihood(
+            log_likelihood = self._dunning_log_likelihood(
                 count_with_period + count_without_period,
                 self._num_period_toks,
                 count_with_period,
@@ -989,7 +992,7 @@ class PunktTrainer(PunktBaseClass):
             f_penalty = int(self.IGNORE_ABBREV_PENALTY) or math.pow(
                 num_nonperiods, -count_without_period
             )
-            score = ll * f_length * f_periods * f_penalty
+            score = log_likelihood * f_length * f_periods * f_penalty
 
             yield typ, score, is_add
 
@@ -1001,7 +1004,7 @@ class PunktTrainer(PunktBaseClass):
         """
         self._params.clear_abbrevs()
         tokens = (typ for typ in self._type_fdist if typ and typ.endswith("."))
-        for abbr, score, is_add in self._reclassify_abbrev_types(tokens):
+        for abbr, score, _is_add in self._reclassify_abbrev_types(tokens):
             if score >= self.ABBREV:
                 self._params.abbrev_types.add(abbr)
 
@@ -1043,7 +1046,7 @@ class PunktTrainer(PunktBaseClass):
         # and (iii) never occus with an uppercase letter
         # sentence-internally.
         # [xx] should the check for (ii) be modified??
-        elif next_tok.first_lower:
+        if next_tok.first_lower:
             typ2 = next_tok.type_no_sentperiod
             typ2ortho_context = self._params.ortho_context[typ2]
             if (typ2ortho_context & _ORTHO_BEG_UC) and not (
@@ -1087,19 +1090,19 @@ class PunktTrainer(PunktBaseClass):
         p1 = count_ab / count_a
         try:
             p2 = (count_b - count_ab) / (N - count_a)
-        except ZeroDivisionError as e:
+        except ZeroDivisionError:
             p2 = 1
 
         try:
             summand1 = count_ab * math.log(p) + (count_a - count_ab) * math.log(1.0 - p)
-        except ValueError as e:
+        except ValueError:
             summand1 = 0
 
         try:
             summand2 = (count_b - count_ab) * math.log(p) + (
                 N - count_a - count_b + count_ab
             ) * math.log(1.0 - p)
-        except ValueError as e:
+        except ValueError:
             summand2 = 0
 
         if count_a == count_ab or p1 <= 0 or p1 >= 1:
@@ -1161,14 +1164,14 @@ class PunktTrainer(PunktBaseClass):
                 and self.MIN_COLLOC_FREQ < col_count <= min(typ1_count, typ2_count)
             ):
 
-                ll = self._col_log_likelihood(
+                log_likelihood = self._col_log_likelihood(
                     typ1_count, typ2_count, col_count, self._type_fdist.N()
                 )
                 # Filter out the not-so-collocative
-                if ll >= self.COLLOCATION and (
+                if log_likelihood >= self.COLLOCATION and (
                     self._type_fdist.N() / typ1_count > typ2_count / col_count
                 ):
-                    yield (typ1, typ2), ll
+                    yield (typ1, typ2), log_likelihood
 
     # ////////////////////////////////////////////////////////////
     # { Sentence-Starter Finder
@@ -1176,7 +1179,7 @@ class PunktTrainer(PunktBaseClass):
 
     def _is_potential_sent_starter(self, cur_tok, prev_tok):
         """
-        Returns True given a token and the token that preceds it if it
+        Returns True given a token and the token that precedes it if it
         seems clear that the token is beginning a sentence.
         """
         # If a token (i) is preceded by a sentece break that is
@@ -1203,7 +1206,7 @@ class PunktTrainer(PunktBaseClass):
                 # needed after freq_threshold
                 continue
 
-            ll = self._col_log_likelihood(
+            log_likelihood = self._col_log_likelihood(
                 self._sentbreak_count,
                 typ_count,
                 typ_at_break_count,
@@ -1211,11 +1214,11 @@ class PunktTrainer(PunktBaseClass):
             )
 
             if (
-                ll >= self.SENT_STARTER
+                log_likelihood >= self.SENT_STARTER
                 and self._type_fdist.N() / self._sentbreak_count
                 > typ_count / typ_at_break_count
             ):
-                yield typ, ll
+                yield typ, log_likelihood
 
     def _get_sentbreak_count(self, tokens):
         """
@@ -1285,27 +1288,30 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
             decision_text = match.group() + match.group("after_tok")
             tokens = self._tokenize_words(decision_text)
             tokens = list(self._annotate_first_pass(tokens))
-            while not tokens[0].period_final:
+            while tokens and not tokens[0].tok.endswith(self._lang_vars.sent_end_chars):
                 tokens.pop(0)
-            yield dict(
-                period_index=match.end() - 1,
-                text=decision_text,
-                type1=tokens[0].type,
-                type2=tokens[1].type,
-                type1_in_abbrs=bool(tokens[0].abbr),
-                type1_is_initial=bool(tokens[0].is_initial),
-                type2_is_sent_starter=tokens[1].type_no_sentperiod
+            yield {
+                "period_index": match.end() - 1,
+                "text": decision_text,
+                "type1": tokens[0].type,
+                "type2": tokens[1].type,
+                "type1_in_abbrs": bool(tokens[0].abbr),
+                "type1_is_initial": bool(tokens[0].is_initial),
+                "type2_is_sent_starter": tokens[1].type_no_sentperiod
                 in self._params.sent_starters,
-                type2_ortho_heuristic=self._ortho_heuristic(tokens[1]),
-                type2_ortho_contexts=set(
+                "type2_ortho_heuristic": self._ortho_heuristic(tokens[1]),
+                "type2_ortho_contexts": set(
                     self._params._debug_ortho_context(tokens[1].type_no_sentperiod)
                 ),
-                collocation=(tokens[0].type_no_sentperiod, tokens[1].type_no_sentperiod)
+                "collocation": (
+                    tokens[0].type_no_sentperiod,
+                    tokens[1].type_no_sentperiod,
+                )
                 in self._params.collocations,
-                reason=self._second_pass_annotation(tokens[0], tokens[1])
+                "reason": self._second_pass_annotation(tokens[0], tokens[1])
                 or REASON_DEFAULT_DECISION,
-                break_decision=tokens[0].sentbreak,
-            )
+                "break_decision": tokens[0].sentbreak,
+            }
 
     def span_tokenize(self, text, realign_boundaries=True):
         """
@@ -1315,8 +1321,8 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         slices = self._slices_from_text(text)
         if realign_boundaries:
             slices = self._realign_boundaries(text, slices)
-        for sl in slices:
-            yield (sl.start, sl.stop)
+        for sentence in slices:
+            yield (sentence.start, sentence.stop)
 
     def sentences_from_text(self, text, realign_boundaries=True):
         """
@@ -1356,31 +1362,31 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
             ["(Sent1.)", "Sent2."].
         """
         realign = 0
-        for sl1, sl2 in _pair_iter(slices):
-            sl1 = slice(sl1.start + realign, sl1.stop)
-            if not sl2:
-                if text[sl1]:
-                    yield sl1
+        for sentence1, sentence2 in _pair_iter(slices):
+            sentence1 = slice(sentence1.start + realign, sentence1.stop)
+            if not sentence2:
+                if text[sentence1]:
+                    yield sentence1
                 continue
 
-            m = self._lang_vars.re_boundary_realignment.match(text[sl2])
+            m = self._lang_vars.re_boundary_realignment.match(text[sentence2])
             if m:
-                yield slice(sl1.start, sl2.start + len(m.group(0).rstrip()))
+                yield slice(sentence1.start, sentence2.start + len(m.group(0).rstrip()))
                 realign = m.end()
             else:
                 realign = 0
-                if text[sl1]:
-                    yield sl1
+                if text[sentence1]:
+                    yield sentence1
 
     def text_contains_sentbreak(self, text):
         """
         Returns True if the given text includes a sentence break.
         """
         found = False  # used to ignore last token
-        for t in self._annotate_tokens(self._tokenize_words(text)):
+        for tok in self._annotate_tokens(self._tokenize_words(text)):
             if found:
                 return True
-            if t.sentbreak:
+            if tok.sentbreak:
                 found = True
         return False
 
@@ -1442,15 +1448,15 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         pos = 0
 
         # A regular expression that finds pieces of whitespace:
-        WS_REGEXP = re.compile(r"\s*")
+        white_space_regexp = re.compile(r"\s*")
 
         sentence = ""
         for aug_tok in tokens:
             tok = aug_tok.tok
 
             # Find the whitespace before this token, and update pos.
-            ws = WS_REGEXP.match(text, pos).group()
-            pos += len(ws)
+            white_space = white_space_regexp.match(text, pos).group()
+            pos += len(white_space)
 
             # Some of the rules used by the punkt word tokenizer
             # strip whitespace out of the text, resulting in tokens
@@ -1471,7 +1477,7 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
             # sentence, then include any whitespace that separated it
             # from the previous token.
             if sentence:
-                sentence += ws
+                sentence += white_space
             sentence += tok
 
             # If we're at a sentence break, then start a new sentence.
@@ -1513,9 +1519,9 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         tokens, making use of the orthographic heuristic (4.1.1), collocation
         heuristic (4.1.2) and frequent sentence starter heuristic (4.1.3).
         """
-        for t1, t2 in _pair_iter(tokens):
-            self._second_pass_annotation(t1, t2)
-            yield t1
+        for token1, token2 in _pair_iter(tokens):
+            self._second_pass_annotation(token1, token2)
+            yield token1
 
     def _second_pass_annotation(self, aug_tok1, aug_tok2):
         """
@@ -1526,13 +1532,10 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         if not aug_tok2:
             return
 
-        tok = aug_tok1.tok
         if not aug_tok1.period_final:
             # We only care about words ending in periods.
             return
-
         typ = aug_tok1.type_no_period
-        next_tok = aug_tok2.tok
         next_typ = aug_tok2.type_no_sentperiod
         tok_is_initial = aug_tok1.is_initial
 
@@ -1582,11 +1585,10 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
                 aug_tok1.abbr = True
                 if tok_is_initial:
                     return REASON_INITIAL_WITH_ORTHOGRAPHIC_HEURISTIC
-                else:
-                    return REASON_NUMBER_WITH_ORTHOGRAPHIC_HEURISTIC
+                return REASON_NUMBER_WITH_ORTHOGRAPHIC_HEURISTIC
 
             # Special heuristic for initials: if orthogrpahic
-            # heuristc is unknown, and next word is always
+            # heuristic is unknown, and next word is always
             # capitalized, then mark as abbrev (eg: J. Bach).
             if (
                 is_sent_starter == "unknown"
@@ -1633,21 +1635,21 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         return "unknown"
 
 
-DEBUG_DECISION_FMT = """Text: %(text)r (at offset %(period_index)d)
-Sentence break? %(break_decision)s (%(reason)s)
-Collocation? %(collocation)s
-%(type1)r:
-    known abbreviation: %(type1_in_abbrs)s
-    is initial: %(type1_is_initial)s
-%(type2)r:
-    known sentence starter: %(type2_is_sent_starter)s
-    orthographic heuristic suggests is a sentence starter? %(type2_ortho_heuristic)s
-    orthographic contexts in training: %(type2_ortho_contexts)s
+DEBUG_DECISION_FMT = """Text: {text!r} (at offset {period_index})
+Sentence break? {break_decision} ({reason})
+Collocation? {collocation}
+{type1!r}:
+    known abbreviation: {type1_in_abbrs}
+    is initial: {type1_is_initial}
+{type2!r}:
+    known sentence starter: {type2_is_sent_starter}
+    orthographic heuristic suggests is a sentence starter? {type2_ortho_heuristic}
+    orthographic contexts in training: {type2_ortho_contexts}
 """
 
 
 def format_debug_decision(d):
-    return DEBUG_DECISION_FMT % d
+    return DEBUG_DECISION_FMT.format(**d)
 
 
 def demo(text, tok_cls=PunktSentenceTokenizer, train_cls=PunktTrainer):
@@ -1659,5 +1661,5 @@ def demo(text, tok_cls=PunktSentenceTokenizer, train_cls=PunktTrainer):
     trainer.INCLUDE_ALL_COLLOCS = True
     trainer.train(text)
     sbd = tok_cls(trainer.get_params())
-    for l in sbd.sentences_from_text(text):
-        print(cleanup(l))
+    for sentence in sbd.sentences_from_text(text):
+        print(cleanup(sentence))
