@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: GDFA word alignment symmetrization
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Authors: Liling Tan
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -20,9 +19,9 @@ def grow_diag_final_and(srclen, trglen, e2f, f2e):
             these criteria: (i) neighbor alignments points are not in the
             intersection and (ii) neighbor alignments are in the union.
 
-    Step 3: Add all other alignment points thats not in the intersection, not in
+    Step 3: Add all other alignment points that are not in the intersection, not in
             the neighboring alignments that met the criteria but in the original
-            foward/backward alignment outputs.
+            forward/backward alignment outputs.
 
         >>> forw = ('0-0 2-1 9-2 21-3 10-4 7-5 11-6 9-7 12-8 1-9 3-10 '
         ...         '4-11 17-12 17-13 25-14 13-15 24-16 11-17 28-18')
