@@ -8,61 +8,72 @@
 
 
 from itertools import chain, product
+from typing import Callable, Iterable, List, Tuple
 
-from nltk.corpus import wordnet
+from nltk.corpus import WordNetCorpusReader, wordnet
+from nltk.stem.api import StemmerI
 from nltk.stem.porter import PorterStemmer
 
 
-def _generate_enums(hypothesis, reference, preprocess=str.lower):
+def _generate_enums(
+    hypothesis: Iterable[str],
+    reference: Iterable[str],
+    preprocess: Callable[[str], str] = str.lower,
+) -> Tuple[List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
-    Takes in string inputs for hypothesis and reference and returns
+    Takes in pre-tokenized inputs for hypothesis and reference and returns
     enumerated word lists for each of them
 
-    :param hypothesis: hypothesis string
-    :type hypothesis: str
-    :param reference: reference string
-    :type reference: str
+    :param hypothesis: pre-tokenized hypothesis
+    :param reference: pre-tokenized reference
     :preprocess: preprocessing method (default str.lower)
-    :type preprocess: method
     :return: enumerated words list
-    :rtype: list of 2D tuples, list of 2D tuples
     """
-    hypothesis_list = list(enumerate(preprocess(hypothesis).split()))
-    reference_list = list(enumerate(preprocess(reference).split()))
-    return hypothesis_list, reference_list
+    if isinstance(hypothesis, str):
+        raise TypeError(
+            f'"hypothesis" expects pre-tokenized hypothesis (Iterable[str]): {hypothesis}'
+        )
+
+    if isinstance(reference, str):
+        raise TypeError(
+            f'"reference" expects pre-tokenized reference (Iterable[str]): {reference}'
+        )
+
+    enum_hypothesis_list = list(enumerate(map(preprocess, hypothesis)))
+    enum_reference_list = list(enumerate(map(preprocess, reference)))
+    return enum_hypothesis_list, enum_reference_list
 
 
-def exact_match(hypothesis, reference):
+def exact_match(
+    hypothesis: Iterable[str], reference: Iterable[str]
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     matches exact words in hypothesis and reference
     and returns a word mapping based on the enumerated
     word id between hypothesis and reference
 
-    :param hypothesis: hypothesis string
-    :type hypothesis: str
-    :param reference: reference string
-    :type reference: str
+    :param hypothesis: pre-tokenized hypothesis
+    :param reference: pre-tokenized reference
     :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
-    :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
-    hypothesis_list, reference_list = _generate_enums(hypothesis, reference)
-    return _match_enums(hypothesis_list, reference_list)
+    enum_hypothesis_list, enum_reference_list = _generate_enums(hypothesis, reference)
+    return _match_enums(enum_hypothesis_list, enum_reference_list)
 
 
-def _match_enums(enum_hypothesis_list, enum_reference_list):
+def _match_enums(
+    enum_hypothesis_list: List[Tuple[int, str]],
+    enum_reference_list: List[Tuple[int, str]],
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     matches exact words in hypothesis and reference and returns
     a word mapping between enum_hypothesis_list and enum_reference_list
     based on the enumerated word id.
 
     :param enum_hypothesis_list: enumerated hypothesis list
-    :type enum_hypothesis_list: list of tuples
     :param enum_reference_list: enumerated reference list
-    :type enum_reference_list: list of 2D tuples
     :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
-    :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
     word_match = []
     for i in range(len(enum_hypothesis_list))[::-1]:
@@ -71,62 +82,64 @@ def _match_enums(enum_hypothesis_list, enum_reference_list):
                 word_match.append(
                     (enum_hypothesis_list[i][0], enum_reference_list[j][0])
                 )
-                (enum_hypothesis_list.pop(i)[1], enum_reference_list.pop(j)[1])
+                enum_hypothesis_list.pop(i)
+                enum_reference_list.pop(j)
                 break
     return word_match, enum_hypothesis_list, enum_reference_list
 
 
 def _enum_stem_match(
-    enum_hypothesis_list, enum_reference_list, stemmer=PorterStemmer()
-):
+    enum_hypothesis_list: List[Tuple[int, str]],
+    enum_reference_list: List[Tuple[int, str]],
+    stemmer: StemmerI = PorterStemmer(),
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     Stems each word and matches them in hypothesis and reference
     and returns a word mapping between enum_hypothesis_list and
     enum_reference_list based on the enumerated word id. The function also
     returns a enumerated list of unmatched words for hypothesis and reference.
 
-    :param enum_hypothesis_list:
-    :type enum_hypothesis_list:
-    :param enum_reference_list:
-    :type enum_reference_list:
+    :param enum_hypothesis_list: enumerated hypothesis list
+    :param enum_reference_list: enumerated reference list
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
-    :type stemmer: nltk.stem.api.StemmerI or any class that implements a stem method
     :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
-    :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
-    stemmed_enum_list1 = [
+    stemmed_enum_hypothesis_list = [
         (word_pair[0], stemmer.stem(word_pair[1])) for word_pair in enum_hypothesis_list
     ]
 
-    stemmed_enum_list2 = [
+    stemmed_enum_reference_list = [
         (word_pair[0], stemmer.stem(word_pair[1])) for word_pair in enum_reference_list
     ]
 
-    return _match_enums(stemmed_enum_list1, stemmed_enum_list2)
+    return _match_enums(stemmed_enum_hypothesis_list, stemmed_enum_reference_list)
 
 
-def stem_match(hypothesis, reference, stemmer=PorterStemmer()):
+def stem_match(
+    hypothesis: Iterable[str],
+    reference: Iterable[str],
+    stemmer: StemmerI = PorterStemmer(),
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     Stems each word and matches them in hypothesis and reference
     and returns a word mapping between hypothesis and reference
 
-    :param hypothesis:
-    :type hypothesis:
-    :param reference:
-    :type reference:
+    :param hypothesis: pre-tokenized hypothesis
+    :param reference: pre-tokenized reference
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
-    :type stemmer: nltk.stem.api.StemmerI or any class that
-                   implements a stem method
     :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
-    :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
     enum_hypothesis_list, enum_reference_list = _generate_enums(hypothesis, reference)
     return _enum_stem_match(enum_hypothesis_list, enum_reference_list, stemmer=stemmer)
 
 
-def _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, wordnet=wordnet):
+def _enum_wordnetsyn_match(
+    enum_hypothesis_list: List[Tuple[int, str]],
+    enum_reference_list: List[Tuple[int, str]],
+    wordnet: WordNetCorpusReader = wordnet,
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     Matches each word in reference to a word in hypothesis
     if any synonym of a hypothesis word is the exact match
@@ -135,10 +148,6 @@ def _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, wordnet=wo
     :param enum_hypothesis_list: enumerated hypothesis list
     :param enum_reference_list: enumerated reference list
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
-    :type wordnet: WordNetCorpusReader
-    :return: list of matched tuples, unmatched hypothesis list, unmatched reference list
-    :rtype:  list of tuples, list of tuples, list of tuples
-
     """
     word_match = []
     for i in range(len(enum_hypothesis_list))[::-1]:
@@ -157,22 +166,25 @@ def _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, wordnet=wo
                 word_match.append(
                     (enum_hypothesis_list[i][0], enum_reference_list[j][0])
                 )
-                enum_hypothesis_list.pop(i), enum_reference_list.pop(j)
+                enum_hypothesis_list.pop(i)
+                enum_reference_list.pop(j)
                 break
     return word_match, enum_hypothesis_list, enum_reference_list
 
 
-def wordnetsyn_match(hypothesis, reference, wordnet=wordnet):
+def wordnetsyn_match(
+    hypothesis: Iterable[str],
+    reference: Iterable[str],
+    wordnet: WordNetCorpusReader = wordnet,
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     Matches each word in reference to a word in hypothesis if any synonym
     of a hypothesis word is the exact match to the reference word.
 
-    :param hypothesis: hypothesis string
-    :param reference: reference string
+    :param hypothesis: pre-tokenized hypothesis
+    :param reference: pre-tokenized reference
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
-    :type wordnet: WordNetCorpusReader
     :return: list of mapped tuples
-    :rtype: list of tuples
     """
     enum_hypothesis_list, enum_reference_list = _generate_enums(hypothesis, reference)
     return _enum_wordnetsyn_match(
@@ -181,8 +193,11 @@ def wordnetsyn_match(hypothesis, reference, wordnet=wordnet):
 
 
 def _enum_align_words(
-    enum_hypothesis_list, enum_reference_list, stemmer=PorterStemmer(), wordnet=wordnet
-):
+    enum_hypothesis_list: List[Tuple[int, str]],
+    enum_reference_list: List[Tuple[int, str]],
+    stemmer: StemmerI = PorterStemmer(),
+    wordnet: WordNetCorpusReader = wordnet,
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     Aligns/matches words in the hypothesis to reference by sequentially
     applying exact match, stemmed match and wordnet based synonym match.
@@ -193,12 +208,9 @@ def _enum_align_words(
     :param enum_hypothesis_list: enumerated hypothesis list
     :param enum_reference_list: enumerated reference list
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
-    :type stemmer: nltk.stem.api.StemmerI or any class that implements a stem method
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
-    :type wordnet: WordNetCorpusReader
     :return: sorted list of matched tuples, unmatched hypothesis list,
              unmatched reference list
-    :rtype: list of tuples, list of tuples, list of tuples
     """
     exact_matches, enum_hypothesis_list, enum_reference_list = _match_enums(
         enum_hypothesis_list, enum_reference_list
@@ -221,21 +233,23 @@ def _enum_align_words(
     )
 
 
-def align_words(hypothesis, reference, stemmer=PorterStemmer(), wordnet=wordnet):
+def align_words(
+    hypothesis: Iterable[str],
+    reference: Iterable[str],
+    stemmer: StemmerI = PorterStemmer(),
+    wordnet: WordNetCorpusReader = wordnet,
+) -> Tuple[List[Tuple[int, int]], List[Tuple[int, str]], List[Tuple[int, str]]]:
     """
     Aligns/matches words in the hypothesis to reference by sequentially
     applying exact match, stemmed match and wordnet based synonym match.
     In case there are multiple matches the match which has the least number
     of crossing is chosen.
 
-    :param hypothesis: hypothesis string
-    :param reference: reference string
+    :param hypothesis: pre-tokenized hypothesis
+    :param reference: pre-tokenized reference
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
-    :type stemmer: nltk.stem.api.StemmerI or any class that implements a stem method
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
-    :type wordnet: WordNetCorpusReader
     :return: sorted list of matched tuples, unmatched hypothesis list, unmatched reference list
-    :rtype: list of tuples, list of tuples, list of tuples
     """
     enum_hypothesis_list, enum_reference_list = _generate_enums(hypothesis, reference)
     return _enum_align_words(
@@ -243,7 +257,7 @@ def align_words(hypothesis, reference, stemmer=PorterStemmer(), wordnet=wordnet)
     )
 
 
-def _count_chunks(matches):
+def _count_chunks(matches: List[Tuple[int, int]]) -> int:
     """
     Counts the fewest possible number of chunks such that matched unigrams
     of each chunk are adjacent to each other. This is used to calculate the
@@ -251,7 +265,6 @@ def _count_chunks(matches):
 
     :param matches: list containing a mapping of matched words (output of align_words)
     :return: Number of chunks a sentence is divided into post alignment
-    :rtype: int
     """
     i = 0
     chunks = 1
@@ -267,15 +280,15 @@ def _count_chunks(matches):
 
 
 def single_meteor_score(
-    reference,
-    hypothesis,
-    preprocess=str.lower,
-    stemmer=PorterStemmer(),
-    wordnet=wordnet,
-    alpha=0.9,
-    beta=3,
-    gamma=0.5,
-):
+    reference: Iterable[str],
+    hypothesis: Iterable[str],
+    preprocess: Callable[[str], str] = str.lower,
+    stemmer: StemmerI = PorterStemmer(),
+    wordnet: WordNetCorpusReader = wordnet,
+    alpha: float = 0.9,
+    beta: float = 3.0,
+    gamma: float = 0.5,
+) -> float:
     """
     Calculates METEOR score for single hypothesis and reference as per
     "Meteor: An Automatic Metric for MT Evaluation with HighLevels of
@@ -284,9 +297,9 @@ def single_meteor_score(
     http://www.cs.cmu.edu/~alavie/METEOR/pdf/Lavie-Agarwal-2007-METEOR.pdf
 
 
-    >>> hypothesis1 = 'It is a guide to action which ensures that the military always obeys the commands of the party'
+    >>> hypothesis1 = ['It', 'is', 'a', 'guide', 'to', 'action', 'which', 'ensures', 'that', 'the', 'military', 'always', 'obeys', 'the', 'commands', 'of', 'the', 'party']
 
-    >>> reference1 = 'It is a guide to action that ensures that the military will forever heed Party commands'
+    >>> reference1 = ['It', 'is', 'a', 'guide', 'to', 'action', 'that', 'ensures', 'that', 'the', 'military', 'will', 'forever', 'heed', 'Party', 'commands']
 
 
     >>> round(single_meteor_score(reference1, hypothesis1),4)
@@ -296,28 +309,19 @@ def single_meteor_score(
         score as 0. We can safely  return a zero instead of raising a
         division by zero error as no match usually implies a bad translation.
 
-    >>> round(meteor_score('this is a cat', 'non matching hypothesis'),4)
+    >>> round(meteor_score(['this', 'is', 'a', 'cat'], ['non', 'matching', 'hypothesis']),4)
     0.0
 
-    :param reference: reference sentence
-    :type reference: str
-    :param hypothesis: a hypothesis sentence
-    :type hypothesis: str
+    :param reference: pre-tokenized reference
+    :param hypothesis: pre-tokenized hypothesis
     :param preprocess: preprocessing function (default str.lower)
-    :type preprocess: method
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
-    :type stemmer: nltk.stem.api.StemmerI or any class that implements a stem method
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
-    :type wordnet: WordNetCorpusReader
     :param alpha: parameter for controlling relative weights of precision and recall.
-    :type alpha: float
     :param beta: parameter for controlling shape of penalty as a
                  function of as a function of fragmentation.
-    :type beta: float
     :param gamma: relative weight assigned to fragmentation penalty.
-    :type gamma: float
     :return: The sentence-level METEOR score.
-    :rtype: float
     """
     enum_hypothesis, enum_reference = _generate_enums(
         hypothesis, reference, preprocess=preprocess
@@ -341,15 +345,15 @@ def single_meteor_score(
 
 
 def meteor_score(
-    references,
-    hypothesis,
-    preprocess=str.lower,
-    stemmer=PorterStemmer(),
-    wordnet=wordnet,
-    alpha=0.9,
-    beta=3,
-    gamma=0.5,
-):
+    references: Iterable[Iterable[str]],
+    hypothesis: Iterable[str],
+    preprocess: Callable[[str], str] = str.lower,
+    stemmer: StemmerI = PorterStemmer(),
+    wordnet: WordNetCorpusReader = wordnet,
+    alpha: float = 0.9,
+    beta: float = 3.0,
+    gamma: float = 0.5,
+) -> float:
     """
     Calculates METEOR score for hypothesis with multiple references as
     described in "Meteor: An Automatic Metric for MT Evaluation with
@@ -362,12 +366,12 @@ def meteor_score(
     iterates over single_meteor_score and picks the best pair among all
     the references for a given hypothesis
 
-    >>> hypothesis1 = 'It is a guide to action which ensures that the military always obeys the commands of the party'
-    >>> hypothesis2 = 'It is to insure the troops forever hearing the activity guidebook that party direct'
+    >>> hypothesis1 = ['It', 'is', 'a', 'guide', 'to', 'action', 'which', 'ensures', 'that', 'the', 'military', 'always', 'obeys', 'the', 'commands', 'of', 'the', 'party']
+    >>> hypothesis2 = ['It', 'is', 'to', 'insure', 'the', 'troops', 'forever', 'hearing', 'the', 'activity', 'guidebook', 'that', 'party', 'direct']
 
-    >>> reference1 = 'It is a guide to action that ensures that the military will forever heed Party commands'
-    >>> reference2 = 'It is the guiding principle which guarantees the military forces always being under the command of the Party'
-    >>> reference3 = 'It is the practical guide for the army always to heed the directions of the party'
+    >>> reference1 = ['It', 'is', 'a', 'guide', 'to', 'action', 'that', 'ensures', 'that', 'the', 'military', 'will', 'forever', 'heed', 'Party', 'commands']
+    >>> reference2 = ['It', 'is', 'the', 'guiding', 'principle', 'which', 'guarantees', 'the', 'military', 'forces', 'always', 'being', 'under', 'the', 'command', 'of', 'the', 'Party']
+    >>> reference3 = ['It', 'is', 'the', 'practical', 'guide', 'for', 'the', 'army', 'always', 'to', 'heed', 'the', 'directions', 'of', 'the', 'party']
 
     >>> round(meteor_score([reference1, reference2, reference3], hypothesis1),4)
     0.7398
@@ -376,28 +380,19 @@ def meteor_score(
         score as 0. We can safely  return a zero instead of raising a
         division by zero error as no match usually implies a bad translation.
 
-    >>> round(meteor_score(['this is a cat'], 'non matching hypothesis'),4)
+    >>> round(meteor_score([['this', 'is', 'a', 'cat']], ['non', 'matching', 'hypothesis']),4)
     0.0
 
-    :param references: reference sentences
-    :type references: list(str)
-    :param hypothesis: a hypothesis sentence
-    :type hypothesis: str
+    :param references: pre-tokenized reference sentences
+    :param hypothesis: a pre-tokenized hypothesis sentence
     :param preprocess: preprocessing function (default str.lower)
-    :type preprocess: method
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
-    :type stemmer: nltk.stem.api.StemmerI or any class that implements a stem method
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
-    :type wordnet: WordNetCorpusReader
     :param alpha: parameter for controlling relative weights of precision and recall.
-    :type alpha: float
     :param beta: parameter for controlling shape of penalty as a function
                  of as a function of fragmentation.
-    :type beta: float
     :param gamma: relative weight assigned to fragmentation penalty.
-    :type gamma: float
     :return: The sentence-level METEOR score.
-    :rtype: float
     """
     return max(
         single_meteor_score(
