@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Twitter API
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>
 #         Lorenzo Rubio <lrnzcig@gmail.com>
 # URL: <http://nltk.org/>
@@ -14,7 +13,7 @@ handling.
 
 import time as _time
 from abc import ABCMeta, abstractmethod
-from datetime import tzinfo, timedelta, timezone, datetime
+from datetime import datetime, timedelta, timezone, tzinfo
 
 
 class LocalTimezoneOffsetWithUTC(tzinfo):
@@ -139,7 +138,7 @@ class TweetHandlerI(BasicTweetHandler):
                     date_limit = self.lower_date_limit
                 if verbose:
                     print(
-                        "Date limit {0} is {1} than date of current tweet {2}".format(
+                        "Date limit {} is {} than date of current tweet {}".format(
                             date_limit, message, tweet_date
                         )
                     )
